@@ -1,3 +1,4 @@
+//@line 41 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/nsContextMenu.js"
 
 /*------------------------------ nsContextMenu ---------------------------------
 |   This JavaScript "class" is used to implement the browser's content-area    |
@@ -9,7 +10,6 @@
 |   longer term, this code will be restructured to make it more reusable.      |
 ------------------------------------------------------------------------------*/
 
-const mailtolength = 7;
 
 function nsContextMenu( xulMenu ) {
     this.target         = null;
@@ -219,71 +219,18 @@ nsContextMenu.prototype = {
 
         // See if the user clicked on an image.
         if ( this.target.nodeType == Node.ELEMENT_NODE ) {
-             if ( this.target instanceof Components.interfaces.nsIImageLoadingContent ) {
+            if ( this.target instanceof Components.interfaces.nsIImageLoadingContent && this.target.currentURI  ) {
                 this.onImage = true;
                 var request = this.target.getRequest( Components.interfaces.nsIImageLoadingContent.CURRENT_REQUEST );
-                if (request && (request.imageStatus & request.STATUS_SIZE_AVAILABLE)
+                if (request && (request.imageStatus & request.STATUS_SIZE_AVAILABLE))
                     this.onLoadedImage = true;
-                this.imageURL = this.target.src;
+                this.imageURL = this.target.currentURI.spec;
 
                 if ( this.target.ownerDocument instanceof ImageDocument )
-                    this.onStandaloneImage = true;
-
-                // Look for image map.
-                var mapName = this.target.getAttribute( "usemap" );
-                if ( mapName ) {
-                    // Find map.
-                    var map = this.target.ownerDocument.getElementById( mapName.substr(1) );
-                    if ( map ) {
-                        // Search child <area>s for a match.
-                        var areas = map.childNodes;
-                        //XXX Client side image maps are too hard for now!
-                        areas.length = 0;
-                        for ( var i = 0; i < areas.length && !this.onLink; i++ ) {
-                            var area = areas[i];
-                            if ( area instanceof HTMLAreaElement ) {
-                                // Get type (rect/circle/polygon/default).
-                                var type = area.getAttribute( "type" );
-                                var coords = this.parseCoords( area );
-                                switch ( type.toUpperCase() ) {
-                                    case "RECT":
-                                    case "RECTANGLE":
-                                        break;
-                                    case "CIRC":
-                                    case "CIRCLE":
-                                        break;
-                                    case "POLY":
-                                    case "POLYGON":
-                                        break;
-                                    case "DEFAULT":
-                                        // Default matches entire image.
-                                        this.onLink = true;
-                                        this.link = area;
-                                        this.onSaveableLink = this.isLinkSaveable( this.link );
-                                        break;
-                                }
-                            }
-                        }
-                    }
-                }
-             } else if ( this.target instanceof HTMLObjectElement
-                         &&
-                         // See if object tag is for an image.
-                         this.objectIsImage( this.target ) ) {
-                // This is an image.
-                this.onImage = true;
-                // URL must be constructed.
-                this.imageURL = this.objectImageURL( this.target );
-             } else if ( this.target instanceof HTMLInputElement ) {
+                   this.onStandaloneImage = true;
+            } else if ( this.target instanceof HTMLInputElement) {
                type = this.target.getAttribute("type");
-               if(type && type.toUpperCase() == "IMAGE") {
-                 this.onImage = true;
-                 // Convert src attribute to absolute URL.
-                 this.imageURL = this.makeURLAbsolute( this.target.baseURI,
-                                                       this.target.src );
-               } else /* if (this.target.getAttribute( "type" ).toUpperCase() == "TEXT") */ {
-                 this.onTextInput = this.isTargetATextBox(this.target);
-               }
+               this.onTextInput = this.isTargetATextBox(this.target);
             } else if ( this.target instanceof HTMLTextAreaElement ) {
                  this.onTextInput = true;
             } else if ( this.target instanceof HTMLHtmlElement ) {
@@ -385,7 +332,6 @@ nsContextMenu.prototype = {
                              ( elem.cite || elem.dateTime ) )                ||
                          ( elem instanceof HTMLElement &&
                              ( elem.title || elem.lang ) ) ) {
-                        dump("On metadata item.\n");
                         this.onMetaDataItem = true;
                     }
                 }
@@ -585,14 +531,30 @@ nsContextMenu.prototype = {
         // Copy the comma-separated list of email addresses only.
         // There are other ways of embedding email addresses in a mailto:
         // link, but such complex parsing is beyond us.
+        
+        const kMailToLength = 7; // length of "mailto:"
+
         var url = this.linkURL();
         var qmark = url.indexOf( "?" );
         var addresses;
         
-        if ( qmark > mailtolength ) 
-            addresses = url.substring( mailtolength, qmark );
-        else 
-            addresses = url.substr( mailtolength );
+        if ( qmark > kMailToLength ) {
+            addresses = url.substring( kMailToLength, qmark );
+        } else {
+            addresses = url.substr( kMailToLength );
+        }
+
+        // Let's try to unescape it using a character set
+        try {
+          var ownerDocument = new XPCNativeWrapper(this.target, "ownerDocument").ownerDocument;
+          var characterSet = new XPCNativeWrapper(ownerDocument, "characterSet").characterSet;
+          const textToSubURI = Components.classes["@mozilla.org/intl/texttosuburi;1"]
+                                         .getService(Components.interfaces.nsITextToSubURI);
+          addresses = textToSubURI.unEscapeURIForUI(characterSet, addresses);
+        }
+        catch(ex) {
+          // Do nothing.
+        }
 
         var clipboard = this.getService( "@mozilla.org/widget/clipboardhelper;1",
                                          Components.interfaces.nsIClipboardHelper );
@@ -602,7 +564,7 @@ nsContextMenu.prototype = {
       var docshell = document.getElementById( "content" ).webNavigation;
       BookmarksUtils.addBookmark( docshell.currentURI.spec,
                                   docshell.document.title,
-                                  docshell.document.charset,
+                                  docshell.document.characterSet,
                                   false );
     },
     addBookmarkForFrame : function() {
@@ -613,7 +575,7 @@ nsContextMenu.prototype = {
         title = uri;
       BookmarksUtils.addBookmark( uri,
                                   title,
-                                  doc.charset,
+                                  doc.characterSet,
                                   false );
     },
     // Open Metadata window for node
@@ -744,7 +706,7 @@ nsContextMenu.prototype = {
     
     searchSelected : function() {
         var focusedWindow = document.commandDispatcher.focusedWindow;
-        var searchStr = focusedWindow.getSelection();
+        var searchStr = focusedWindow.getSelection();;
         searchStr = searchStr.toString();
         searchStr = searchStr.replace( /^\s+/, "" );
         searchStr = searchStr.replace(/(\n|\r|\t)+/g, " ");
@@ -752,26 +714,6 @@ nsContextMenu.prototype = {
         return searchStr;
     },
     
-    // Determine if target <object> is an image.
-    objectIsImage : function ( objElem ) {
-        var result = false;
-        // Get type and data attributes.
-        var type = objElem.getAttribute( "type" );
-        var data = objElem.getAttribute( "data" );
-        // Presume any mime type of the form "image/..." is an image.
-        // There must be a data= attribute with an URL, also.
-        if ( type.substring( 0, 6 ) == "image/" && data && data != "" ) {
-            result = true;
-        }
-        return result;
-    },
-    // Extract image URL from <object> tag.
-    objectImageURL : function ( objElem ) {
-        // Extract url from data= attribute.
-        var data = objElem.getAttribute( "data" );
-        // Make it absolute.
-        return this.makeURLAbsolute( objElem.baseURI, data );
-    },
     // Convert relative URL to absolute, using document's <base>.
     makeURLAbsolute : function ( base, url ) {
         // Construct nsIURL.
@@ -782,10 +724,6 @@ nsContextMenu.prototype = {
         return ioService.newURI(baseURI.resolve(url), null, null).spec;
     },
 
-    // Parse coords= attribute and return array.
-    parseCoords : function ( area ) {
-        return [];
-    },
     toString : function () {
         return "contextMenu.target     = " + this.target + "\n" +
                "contextMenu.onImage    = " + this.onImage + "\n" +
@@ -832,7 +770,7 @@ function nsDefaultEngine()
         var pb = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);
         var pbi = pb.QueryInterface(
-                    Components.interfaces.nsIPrefBranchInternal);
+                    Components.interfaces.nsIPrefBranch2);
         pbi.addObserver(this.domain, this, false);
 
         // reuse code by explicitly invoking initial |observe| call
