@@ -1,11 +1,11 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* ***** BEGIN LICENSE BLOCK *****
- * Version: NPL 1.1/GPL 2.0/LGPL 2.1
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
- * The contents of this file are subject to the Netscape Public License
- * Version 1.1 (the "License"); you may not use this file except in
- * compliance with the License. You may obtain a copy of the License at
- * http://www.mozilla.org/NPL/
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
  *
  * Software distributed under the License is distributed on an "AS IS" basis,
  * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
@@ -14,24 +14,25 @@
  *
  * The Original Code is mozilla.org code.
  *
- * The Initial Developer of the Original Code is 
+ * The Initial Developer of the Original Code is
  * Netscape Communications Corporation.
  * Portions created by the Initial Developer are Copyright (C) 1998
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
+ *   Dan Mosedale <dan.mosedale@oracle.com>
  *
  * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or 
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * either of the GNU General Public License Version 2 or later (the "GPL"),
+ * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
  * in which case the provisions of the GPL or the LGPL are applicable instead
  * of those above. If you wish to allow use of your version of this file only
  * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the NPL, indicate your
+ * use your version of this file under the terms of the MPL, indicate your
  * decision by deleting the provisions above and replace them with the notice
  * and other provisions required by the GPL or the LGPL. If you do not delete
  * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the NPL, the GPL or the LGPL.
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *
  * ***** END LICENSE BLOCK ***** */
 
@@ -53,9 +54,6 @@
 //     mail file at the same time
 pref("mail.migration.copyMailFiles", true);
 
-// pref defined by stand alone mail apps
-pref("mail.standalone", true);
-
 //mailnews.timeline_is_enabled should be set to true ONLY for perf measurement-timeline builds.
 pref("mailnews.timeline_is_enabled", false);
 
@@ -70,13 +68,13 @@ pref("mailnews.auto_unzip_saved_attachments", false);
 // is displayed in the message pane or not...
 pref("mailnews.headers.showUserAgent",       false);
 
-// hidden pref for changing how we present attachments in the message pane
-pref("mailnews.attachments.display.largeView", false);
-
 // hidden pref for controlling if the organization string
 // is displayed in the message pane or not...
 pref("mailnews.headers.showOrganization",    false);
 
+// mailnews tcp read+write timeout in seconds.
+pref("mailnews.tcptimeout", 60);
+
 // Mail server preferences, pop by default
 pref("mail.server_type",	0); 	// 0 pop, 1 imap,
 					// (Unix only:)
@@ -86,6 +84,9 @@ pref("mail.auth_login", true);
 pref("mail.default_drafts", "");    // empty string use default Drafts name;
 pref("mail.default_templates", ""); // empty string use default Templates name
 
+// check all folders for new mail
+pref("mail.check_all_imap_folders_for_new", false);
+
 pref("mail.imap.server_sub_directory",      "");
 pref("mail.imap.max_cached_connections",    10);
 pref("mail.imap.fetch_by_chunks",           true);
@@ -103,7 +104,10 @@ pref("mail.imap.cleanup_inbox_on_exit",     false);
 pref("mail.imap.mime_parts_on_demand",      true);
 pref("mail.imap.mime_parts_on_demand_max_depth", 15);
 pref("mail.imap.mime_parts_on_demand_threshold", 30000);
-pref("mail.thread_without_re",	            true);
+pref("mail.imap.use_literal_plus",          true);
+pref("mail.imap.check_deleted_before_expunge", false);
+pref("mail.thread_without_re",	            true);  // if false, only thread by subject if Re:
+pref("mail.strict_threading",               false); // if true, don't thread by suject at all
 pref("mail.leave_on_server",                false);
 pref("mail.default_cc",                     "");
 pref("mail.default_fcc",                    ""); // maibox:URL or Imap://Host/OnLineFolderName
@@ -127,10 +131,11 @@ pref("mail.use_fcc",                        true);
 pref("mail.cc_self",                        false);
 pref("mail.strictly_mime",                  false);
 pref("mail.strictly_mime_headers",          true);
+pref("mail.strictly_mime.parm_folding",     2);  // 0/1 (RFC 2047), 2(RFC 2231)
+pref("mail.label_ascii_only_mail_as_us_ascii", false); 
 pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config",                    0);
-pref("mail.pane_config.dynamic",            0); // new pref used for dynamic pane configuration
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
@@ -152,6 +157,8 @@ pref("mail.html_compose",                   true);
 // this will show up in the address picker in the compose window
 // examples: "X-Face" or "Approved,X-No-Archive"
 pref("mail.compose.other.header",	    "");
+pref("mail.compose.autosave", false);
+pref("mail.compose.autosaveinterval", 5); // in minutes
 pref("mail.fcc_folder",                     "");
 pref("mail.encrypt_outgoing_mail",          false);
 pref("mail.crypto_sign_outgoing_mail",      false);
@@ -176,6 +183,9 @@ pref("news.fcc_folder",                     "");
 pref("news.notify.on",                      true);
 pref("news.max_articles",                   500);
 pref("news.mark_old_read",                  false);
+pref("news.show_size_in_lines",             true);
+pref("news.update_unread_on_expand",        true);
+pref("news.get_messages_on_select",         true);
 
 pref("mailnews.wraplength",                 72);
 pref("mail.compose.wrap_to_window_width",   false);
@@ -185,7 +195,8 @@ pref("mailnews.reply_header_type",          1);
 // locale which affects date format, set empty string to use application default locale
 pref("mailnews.reply_header_locale",        "");
 pref("mailnews.reply_header_authorwrote",   "chrome://messenger/locale/messengercompose/composeMsgs.properties");
-pref("mailnews.reply_header_ondate",        "On %s");
+pref("mailnews.reply_header_ondate",        "chrome://messenger/locale/messengercompose/composeMsgs.properties");
+
 // separator to separate between date and author
 pref("mailnews.reply_header_separator",     ", ");
 pref("mailnews.reply_header_colon",         ":");
@@ -199,11 +210,11 @@ pref("mailnews.offline_sync_news",         false);
 pref("mailnews.offline_sync_send_unsent",  true);
 pref("mailnews.offline_sync_work_offline", false);   
 pref("mailnews.force_ascii_search",         false);
-pref("mailnews.autolookup_unknown_mime_types",  true);
 
 pref("mailnews.send_default_charset",       "chrome://messenger/locale/messenger.properties");
 pref("mailnews.view_default_charset",       "chrome://messenger/locale/messenger.properties");
 pref("mailnews.force_charset_override",     false);
+pref("mailnews.reply_in_default_charset",   false);
 
 pref("mailnews.search_date_format",        "chrome://messenger/locale/messenger.properties");
 pref("mailnews.search_date_separator",     "chrome://messenger/locale/messenger.properties");
@@ -212,6 +223,9 @@ pref("mailnews.language_sensitive_font",    true);
 
 pref("mailnews.quotingPrefs.version",       0);  // used to decide whether to migrate global quoting prefs
 
+// the first time, we'll warn the user about the blind send, and they can disable the warning if they want.
+pref("mapi.blind-send.enabled",             true);  
+
 pref("offline.news.download.unread_only",   true);
 pref("offline.news.download.by_date",       true);
 pref("offline.news.download.days",          30);    // days
@@ -260,6 +274,45 @@ pref("ldap_2.servers.history.description",						"chrome://messenger/locale/addre
 pref("ldap_2.servers.history.dirType",							2);
 pref("ldap_2.servers.history.isOffline",						false);
 
+// default mapping of addressbook properties to ldap attributes
+pref("ldap_2.servers.default.attrmap.FirstName", "givenName");
+pref("ldap_2.servers.default.attrmap.LastName", "sn,surname");
+pref("ldap_2.servers.default.attrmap.DisplayName", "displayName,cn,commonname");
+pref("ldap_2.servers.default.attrmap.NickName", "mozillaNickname,xmozillanickname");
+pref("ldap_2.servers.default.attrmap.PrimaryEmail", "mail");
+pref("ldap_2.servers.default.attrmap.SecondEmail", "mozillaSecondEmail,xmozillasecondemail");
+pref("ldap_2.servers.default.attrmap.WorkPhone", "telephoneNumber");
+pref("ldap_2.servers.default.attrmap.HomePhone", "homePhone");
+pref("ldap_2.servers.default.attrmap.FaxNumber", "fax,facsimiletelephonenumber");
+pref("ldap_2.servers.default.attrmap.PagerNumber", "pager,pagerphone");
+pref("ldap_2.servers.default.attrmap.CellularNumber", "mobile,cellphone,carphone");
+pref("ldap_2.servers.default.attrmap.WorkAddress", "street,streetaddress,postOfficeBox");
+pref("ldap_2.servers.default.attrmap.HomeAddress", "mozillaHomeStreet");
+pref("ldap_2.servers.default.attrmap.WorkAddress2", "mozillaWorkStreet2");
+pref("ldap_2.servers.default.attrmap.HomeAddress2", "mozillaHomeStreet2");
+pref("ldap_2.servers.default.attrmap.WorkCity", "l,locality");
+pref("ldap_2.servers.default.attrmap.HomeCity", "mozillaHomeLocalityName");
+pref("ldap_2.servers.default.attrmap.WorkState", "st,region");
+pref("ldap_2.servers.default.attrmap.HomeState", "mozillaHomeState");
+pref("ldap_2.servers.default.attrmap.WorkZipCode", "postalCode,zip");
+pref("ldap_2.servers.default.attrmap.HomeZipCode", "mozillaHomePostalCode");
+pref("ldap_2.servers.default.attrmap.WorkCountry", "c,countryname");
+pref("ldap_2.servers.default.attrmap.HomeCountry", "mozillaHomeCountryName");
+pref("ldap_2.servers.default.attrmap.JobTitle", "title");
+pref("ldap_2.servers.default.attrmap.Department", "department,departmentnumber,ou,orgunit");
+pref("ldap_2.servers.default.attrmap.Company", "company,o");
+pref("ldap_2.servers.default.attrmap._AimScreenName", "nsAIMid,nscpaimscreenname");
+pref("ldap_2.servers.default.attrmap.WebPage1", "mozillaWorkUrl,workurl");
+pref("ldap_2.servers.default.attrmap.WebPage2", "mozillaHomeUrl,homeurl");
+pref("ldap_2.servers.default.attrmap.BirthYear", "birthyear");
+pref("ldap_2.servers.default.attrmap.Custom1", "mozillaCustom1,custom1");
+pref("ldap_2.servers.default.attrmap.Custom2", "mozillaCustom2,custom2");
+pref("ldap_2.servers.default.attrmap.Custom3", "mozillaCustom3,custom3");
+pref("ldap_2.servers.default.attrmap.Custom4", "mozillaCustom4,custom4");
+pref("ldap_2.servers.default.attrmap.Notes", "description,notes");
+pref("ldap_2.servers.default.attrmap.PreferMailFormat", "mozillaUseHtmlMail,xmozillausehtmlmail");
+pref("ldap_2.servers.default.attrmap.LastModifiedDate", "modifytimestamp");
+
 
 // A position of zero is a special value that indicates the directory is deleted.
 // These entries are provided to keep the (obsolete) Four11 directory and the
@@ -287,11 +340,22 @@ pref("ldap_2.prefs_migrated",      false);
 pref("mailnews.confirm.moveFoldersToTrash", true);
 
 pref("mailnews.reuse_message_window", true);
+pref("mailnews.open_window_warning", 10); // warn user if they attempt to open more than this many messages at once
 
 pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mailnews.start_page.enabled", true);
 
 pref("mailnews.remember_selected_message", true);
+pref("mailnews.scroll_to_new_message", true);
+
+/* file, print, and stop hidden by default.  
+   see http://bugzilla.mozilla.org/show_bug.cgi?id=197729#c3 */
+pref("mail.toolbars.showbutton.file", false);
+pref("mail.toolbars.showbutton.next", true);
+pref("mail.toolbars.showbutton.junk", true);
+pref("mail.toolbars.showbutton.print",false);
+pref("mail.toolbars.showbutton.stop", false);
+
 pref("mailnews.thread_pane_column_unthreads", true);
 
 pref("mailnews.account_central_page.url", "chrome://messenger/locale/messenger.properties");
@@ -301,9 +365,15 @@ pref("mail.identity.default.compose_html", true);
 pref("mail.identity.default.valid", true);
 pref("mail.identity.default.fcc",true);
 pref("mail.identity.default.fcc_folder","mailbox://nobody@Local%20Folders/Sent");
+pref("mail.identity.default.autocompleteToMyDomain", false);
+
+// keep these defaults for backwards compatibility and migration
+
+// but .doBcc and .doBccList are the right ones from now on.
 pref("mail.identity.default.bcc_self",false);
 pref("mail.identity.default.bcc_others",false);
 pref("mail.identity.default.bcc_list","");
+
 pref("mail.identity.default.draft_folder","mailbox://nobody@Local%20Folders/Drafts");
 pref("mail.identity.default.stationery_folder","mailbox://nobody@Local%20Folders/Templates");
 pref("mail.identity.default.directoryServer","");
@@ -311,7 +381,6 @@ pref("mail.identity.default.overrideGlobal_Pref", false);
 pref("mail.identity.default.auto_quote", true);
 pref("mail.identity.default.reply_on_top", 0); // 0=bottom 1=top 2=select
 pref("mail.identity.default.sig_bottom", true); // true=below quoted false=above quoted
-
 // Headers to always add to outgoing mail
 // examples: "header1,header2"
 // pref("mail.identity.id1.headers", "header1");
@@ -346,7 +415,9 @@ pref("mail.server.default.valid", true);
 pref("mail.server.default.abbreviate",true);
 pref("mail.server.default.isSecure", false);
 pref("mail.server.default.useSecAuth", false);
+pref("mail.server.default.socketType", 0);
 pref("mail.server.default.override_namespaces", true);
+pref("mail.server.default.deferred_to_account", "");
 
 pref("mail.server.default.delete_model", 1);
 pref("mail.server.default.fetch_by_chunks", true);
@@ -358,6 +429,11 @@ pref("mail.server.default.max_articles", 500);
 pref("mail.server.default.notify.on", true);
 pref("mail.server.default.mark_old_read", false);
 pref("mail.server.default.empty_trash_on_exit", false);
+// 0 = Keep Dupes, leave them alone
+// 1 = delete dupes
+// 2 = Move Dupes to trash
+// 3 = Mark Dupes as Read
+pref("mail.server.default.dup_action", 0);
 
 pref("mail.server.default.using_subscription", true);
 pref("mail.server.default.dual_use_folders", true);
@@ -366,25 +442,43 @@ pref("mail.server.default.login_at_startup", false);
 pref("mail.server.default.allows_specialfolders_usage", true);
 pref("mail.server.default.canCreateFolders", true);
 pref("mail.server.default.canFileMessages", true);
+pref("mail.server.default.logon_fallback", true);
 
 // special enhancements for IMAP servers
 pref("mail.server.default.store_read_mail_in_pfc", false);  
 pref("mail.server.default.store_sent_mail_in_pfc", false);  
-
+pref("mail.server.default.use_idle", true); 
 // for spam
-pref("mail.server.default.spamLevel",0);  // 0 off, 100 on.  not doing bool since we might have real levels one day.
+pref("mail.server.default.spamLevel",100);  // 0 off, 100 on.  not doing bool since we might have real levels one day.
 pref("mail.server.default.moveOnSpam",false);
+pref("mail.server.default.markAsReadOnSpam",false);
 pref("mail.server.default.moveTargetMode",0); // 0 == "Junk" on server, 1 == specific folder
 pref("mail.server.default.spamActionTargetAccount","");
 pref("mail.server.default.spamActionTargetFolder","");
 pref("mail.server.default.useWhiteList",true);
 pref("mail.server.default.whiteListAbURI","moz-abmdbdirectory://abook.mab");  // the Personal addressbook.
+pref("mail.server.default.useServerFilter", false);
+pref("mail.server.default.serverFilterTrustFlags", 1); // 1 == trust positives, 2 == trust negatives, 3 == trust both
 pref("mail.server.default.purgeSpam",false);
 pref("mail.server.default.purgeSpamInterval",14); // 14 days
 pref("mail.server.default.spamLoggingEnabled",false);
 pref("mail.server.default.manualMark",false);
-pref("mail.server.default.manualMarkMode",0); // 0 == "move to junk folder", 1 = "delete"
+pref("mail.server.default.manualMarkMode",0); // 0 == "move to junk folder", 1 == "delete"
 
+// the probablilty threshold over which messages are classified as junk
+// this number is divided by 100 before it is used. The classifier can be fine tuned
+// by changing this pref. Typical values are .99, .95, .90, .5, etc. 
+pref("mail.adaptivefilters.junk_threshold", 90); 
+
+pref("mail.autoComplete.highlightNonMatches", true);
+
+// if true, we'll use the password from an incoming server with
+// matching username and domain
+pref("mail.smtp.useMatchingDomainServer", false);
+
+// if true, we'll use the password from an incoming server with
+// matching username and host name
+pref("mail.smtp.useMatchingHostNameServer", false);
 
 pref("mail.smtpserver.default.auth_method", 1); // auth any
 pref("mail.smtpserver.default.trySecAuth", true);
@@ -395,9 +489,7 @@ pref("mail.display_glyph", true);   // TXT->HTML :-) etc. in viewer
 pref("mail.display_struct", true);  // TXT->HTML *bold* etc. in viewer; ditto
 pref("mail.send_struct", false);   // HTML->HTML *bold* etc. during Send; ditto
 pref("mailnews.display.original_date", false);   // display date string from mail headers without interpreting
-
-pref("mailnews.display.sanitizeJunkMail", true);
-
+// For the next 4 prefs, see <http://www.bucksch.org/1/projects/mozilla/108153>
 pref("mailnews.display.prefer_plaintext", false);  // Ignore HTML parts in multipart/alternative
 pref("mailnews.display.html_as", 0);  // How to display HTML parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML
 pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul(type,compact) ol(type,compact,start) li(type,value) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc,src) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign)");
@@ -419,8 +511,6 @@ pref("mail.startup.enabledMailCheckOnce", false);
 pref("mailnews.max_header_display_length",3); // number of addresses to show
 
 pref("messenger.throbber.url","chrome://messenger-region/locale/region.properties");
-pref("mailnews.release_notes.url","chrome://messenger-region/locale/region.properties");
-pref("mailnews.hints_and_tips.url","chrome://messenger-region/locale/region.properties");
 pref("compose.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("addressbook.throbber.url","chrome://messenger-region/locale/region.properties");
 
@@ -432,6 +522,8 @@ pref("mailnews.nav_crosses_folders", 1); // prompt user when crossing folders
 pref("news.cancel.confirm",true);
 pref("news.cancel.alert_on_success",true);
 pref("mail.SpellCheckBeforeSend",false);
+pref("mail.spellcheck.inline",true);
+pref("mail.phishing.detection.enabled", true); // enable / disable phishing detection for link clicks
 pref("mail.warn_on_send_accel_key", true);
 pref("mail.enable_autocomplete",true);
 pref("mailnews.html_domains","");
@@ -440,6 +532,8 @@ pref("mailnews.global_html_domains.version",1);
 
 pref("mail.imap.use_status_for_biff", true);
 
+// Pref controlling confirmation of folder deletion on empty trash
+pref("mail.imap.confirm_emptyTrashFolderDeletion", false);
 // Pref controlling the updates on the pre-configured accounts.
 // In order to add new pre-configured accounts (after a version),
 // increase the following version number besides updating the
@@ -464,18 +558,39 @@ pref("mail.content_disposition_type", 0);
 
 pref("mailnews.show_send_progress", true); //Will show a progress dialog when saving or sending a message
 pref("mail.server.default.retainBy", 1);
+
 pref("mailnews.ui.junk.firstuse", true);
 
+// for manual upgrades of certain UI features.
+// 1 -> 2 is for the folder pane tree landing, to hide the
+// unread and total columns, see msgMail3PaneWindow.js
+pref("mail.ui.folderpane.version", 1);                                          
+
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the thread pane tree landing, to hide the
 // labels column, see msgMail3PaneWindow.js
 // 2 -> 3 is for the junk status column
-// 3 -> 4 is for the sender column
-// 4 -> 5 is for the attachment column
 pref("mailnews.ui.threadpane.version", 1);
-
-pref("mail.showFolderPaneColumns", false); // setting to true will allow total/unread/size columns
-
+// for manual upgrades of certain UI features.
+// 1 -> 2 is for the ab results pane tree landing
+// to hide the non default columns in the addressbook dialog
+// see abCommon.js and addressbook.js
+pref("mailnews.ui.addressbook_results.version", 1);                                          
+// for manual upgrades of certain UI features.
+// 1 -> 2 is for the ab results pane tree landing
+// to hide the non default columns in the addressbook sidebar panel
+// see abCommon.js and addressbook-panel.js
+pref("mailnews.ui.addressbook_panel_results.version", 1);                                          
+// for manual upgrades of certain UI features.
+// 1 -> 2 is for the ab results pane tree landing
+// to hide the non default columns in the select addresses dialog
+// see abCommon.js and abSelectAddressesDialog.js
+pref("mailnews.ui.select_addresses_results.version", 1); 
+// for manual upgrades of certain UI features.
+// 1 -> 2 is for the ab results pane
+// to hide the non default columns in the advanced directory search dialog
+// see abCommon.js and ABSearchDialog.js
+pref("mailnews.ui.advanced_directory_search_results.version", 1);                                         
 //If set to a number greater than 0, msg compose windows will be recycled in order to open them quickly
 pref("mail.compose.max_recycled_windows", 1); 
 
@@ -512,17 +627,23 @@ pref("mailnews.fakeaccount.server", "");
 
 // message display properties
 pref("mailnews.message_display.disable_remote_image", false);
-pref("mailnews.message_display.allow.plugins", false);
+pref("mailnews.message_display.allow.plugins", true);
+
+// default msg compose font prefs
+pref("msgcompose.font_face",                "");
+pref("msgcompose.font_size",                "medium");
+pref("msgcompose.text_color",               "#000000");
+pref("msgcompose.background_color",         "#FFFFFF");
 
 // When there is no disclosed recipients (only bcc), we should address the message to empty group
 // to prevent some mail server to disclose the bcc recipients
 pref("mail.compose.add_undisclosed_recipients", true);
 
+// these prefs (in minutes) are here to help QA test this feature
 // "mail.purge.min_delay", never purge a junk folder more than once every 480 minutes (60 mins/hour * 8 hours)
-pref("mail.purge.min_delay",480);
 // "mail.purge.timer_interval", fire the purge timer every 5 minutes, starting 5 minutes after we load accounts
-pref("mail.purge.timer_interval",5);
-pref("mailnews.view.last",0); // 0 == "all" view
+pref("mail.purge.min_delay",480);
+pref("mail.purge.timer_interval",5); 
 
 // set to true if viewing a message should mark it as read only if the msg is viewed for a specified time interval in seconds
 pref("mailnews.mark_message_read.delay", false); 
@@ -530,3 +651,32 @@ pref("mailnews.mark_message_read.delay.interval", 5); // measured in seconds
 
 // require a password before showing imap or local headers in thread pane
 pref("mail.password_protect_local_cache", false);
+// to reduce forking in the js / C++
+// overridden by stand alone mail
+pref("mail.standalone", false);
+
+// import option to skip the first record, recorded so that we can save
+// the users last used preference.
+pref("mailnews.import.text.skipfirstrecord", true);
+
+//@line 669 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+
+//@line 672 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+pref("mail.empty_trash", false);
+
+pref("mail.check_new_mail", true);
+pref("mail.signature_file", "~/.signature");
+pref("mail.default_fcc", "~/nsmail/Sent");
+pref("news.default_fcc", "~/nsmail/Sent");
+pref("mailnews.reply_with_extra_lines", 0);
+pref("mail.use_builtin_movemail", true);
+pref("mail.movemail_program", "");
+pref("mail.movemail_warn", false);
+pref("mail.sash_geometry", "");
+pref("news.cache_xover", false);
+pref("news.show_first_unread", false);
+pref("news.sash_geometry", "");
+pref("mail.signature_date", 0);
+
+//@line 691 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mailnews/mailnews.js"
+
