@@ -1,3 +1,4 @@
+//@line 44 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/toolkit/components/filepicker/content/filepicker.js"
 
 const nsIFilePicker       = Components.interfaces.nsIFilePicker;
 const nsIDirectoryServiceProvider = Components.interfaces.nsIDirectoryServiceProvider;
@@ -41,12 +42,13 @@ function filepickerLoad() {
     if (o.displayDirectory) {
       const directory = o.displayDirectory.path;
     }
+
     const initialText = o.defaultString;
     const filterTitles = o.filters.titles;
     const filterTypes = o.filters.types;
     const numFilters = filterTitles.length;
 
-    window.title = title;
+    document.title = title;
 
     if (initialText) {
       textInput.value = initialText;
@@ -95,13 +97,18 @@ function filepickerLoad() {
     treeView.showOnlyDirectories = true;
   }
 
+  // set up the right icon
+  if (filePickerMode == nsIFilePicker.modeSave)
+    okButton.setAttribute("icon","save");
+  else
+    okButton.setAttribute("icon","open");
+
   // start out with a filename sort
   handleColumnClick("FilenameColumn");
 
   document.documentElement.setAttribute("ondialogcancel", "return onCancel();");
   try {
-    var buttonLabel = getOKAction();
-    okButton.setAttribute("label", buttonLabel);
+    setOKAction();
   } catch (exception) {
     // keep it set to "OK"
   }
@@ -470,8 +477,9 @@ function onTreeFocus(event) {
   onFileSelected(treeView.selectedFiles);
 }
 
-function getOKAction(file) {
+function setOKAction(file) {
   var buttonLabel;
+  var buttonIcon = "open"; // used in all but one case
 
   if (file && file.isDirectory() && filePickerMode != nsIFilePicker.modeGetFolder) {
     document.documentElement.setAttribute("ondialogaccept", "return openOnOK();");
@@ -489,11 +497,12 @@ function getOKAction(file) {
       break;
     case nsIFilePicker.modeSave:
       buttonLabel = gFilePickerBundle.getString("saveButtonLabel");
+      buttonIcon = "save";
       break;
     }
   }
-
-  return buttonLabel;
+  okButton.setAttribute("label", buttonLabel);
+  okButton.setAttribute("icon", buttonIcon);
 }
 
 function onSelect(event) {
@@ -532,8 +541,7 @@ function onFileSelected(/* nsIArray */ selectedFileList) {
   }
 
   if (validFileSelected) {
-    var buttonLabel = getOKAction(file);
-    okButton.setAttribute("label", buttonLabel);
+    setOKAction(file);
     okButton.disabled = invalidSelection;
   } else
     okButton.disabled = (textInput.value == "");
@@ -560,8 +568,7 @@ function addToTextFieldValue(path)
 }
 
 function onTextFieldFocus() {
-  var buttonLabel = getOKAction(null);
-  okButton.setAttribute("label", buttonLabel);
+  setOKAction(null);
   doEnabling();
 }
 
