@@ -1,3 +1,4 @@
+//@line 36 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/ABSearchDialog.js"
 
 var searchSessionContractID = "@mozilla.org/messenger/searchSession;1";
 var gSearchSession;
@@ -21,9 +22,18 @@ var gRDF = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Compo
 
 var gSearchAbViewListener = {
   onSelectionChanged: function() {
+    UpdateCardView();
   },
   onCountChanged: function(total) {
-    var statusText = gAddressBookBundle.getFormattedString("matchesFound", [total]);   
+    if (total == 0)
+      var statusText = gAddressBookBundle.getString("noMatchFound");
+    else
+    {
+      if (total == 1)
+        var statusText = gAddressBookBundle.getString("matchFound");
+      else  
+        var statusText = gAddressBookBundle.getFormattedString("matchesFound", [total]);
+    }
     gStatusText.setAttribute("label", statusText);
   }
 };
@@ -34,13 +44,15 @@ function searchOnLoad()
   initializeSearchWindowWidgets();
 
   gSearchBundle = document.getElementById("bundle_search");
+  gSearchStopButton.setAttribute("label", gSearchBundle.getString("labelForSearchButton"));
+  gSearchStopButton.setAttribute("accesskey", gSearchBundle.getString("accesskeyForSearchButton"));
   gAddressBookBundle = document.getElementById("bundle_addressBook");
   gSearchSession = Components.classes[searchSessionContractID].createInstance(Components.interfaces.nsIMsgSearchSession);
 
   // initialize a flag for phonetic name search
   var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                               .getService(Components.interfaces.nsIPrefService);
-  var prefBranch = prefService.getBranch(null).QueryInterface(Components.interfaces.nsIPrefBranchInternal);
+  var prefBranch = prefService.getBranch(null).QueryInterface(Components.interfaces.nsIPrefBranch2);
   gSearchPhoneticName =
         prefBranch.getComplexValue("mail.addr_book.show_phonetic_fields", 
                                    Components.interfaces.nsIPrefLocalizedString).data;
@@ -93,22 +105,7 @@ function SelectDirectory(aURI)
   // set popup with address book names
   var abPopup = document.getElementById('abPopup');
   if ( abPopup )
-  {
-    var menupopup = document.getElementById('abPopup-menupopup');
-
-    if ( selectedAB && menupopup && menupopup.childNodes )
-    {
-      for ( var index = menupopup.childNodes.length - 1; index >= 0; index-- )
-      {
-        if ( menupopup.childNodes[index].getAttribute('value') == selectedAB )
-        {
-          abPopup.label = menupopup.childNodes[index].getAttribute('label');
-          abPopup.value = menupopup.childNodes[index].getAttribute('value');
-          break;
-        }
-      }
-    }
-  }
+    abPopup.value = selectedAB;
 
   setSearchScope(GetScopeForDirectoryURI(selectedAB));
 }
@@ -304,6 +301,12 @@ function onCompose()
   AbNewMessage();
 }
 
+function AbResultsPaneKeyPress(event)
+{
+  if (event.keyCode == 13)
+    AbEditSelectedCard();
+}
+
 function AbResultsPaneDoubleClick(card)
 {
   AbEditCard(card);
