@@ -1,3 +1,4 @@
+//@line 41 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/components/addrbook/content/abCommon.js"
 
 var dirTree = 0;
 var abList = 0;
@@ -31,6 +32,8 @@ var ResultsPaneController =
       case "cmd_delete":
       case "button_delete":
       case "button_edit":
+      case "cmd_printcard":
+      case "cmd_printcardpreview":
         return true;
       default:
         return false;
@@ -63,6 +66,8 @@ var ResultsPaneController =
             goSetMenuValue(command, "valueCards");
         }
         return (enabled && (numSelected > 0));
+      case "cmd_printcard":
+      case "cmd_printcardpreview":
       case "button_edit":
         return (GetSelectedCardIndex() != -1);
       default:
@@ -84,6 +89,12 @@ var ResultsPaneController =
       case "button_edit":
         AbEditSelectedCard();
         break;
+      case "cmd_printcard":
+        AbPrintCard();
+        break;
+      case "cmd_printcardpreview":
+        AbPrintPreviewCard();
+        break;
     }
   },
 
@@ -106,6 +117,8 @@ var DirPaneController =
       case "cmd_delete":
       case "button_delete":
       case "button_edit":
+      case "cmd_printcard":
+      case "cmd_printcardpreview":
         return true;
       default:
         return false;
@@ -156,6 +169,9 @@ var DirPaneController =
         }
         else
           return false;
+      case "cmd_printcard":
+      case "cmd_printcardpreview":
+        return (GetSelectedCardIndex() != -1);
       case "button_edit":
         return (GetSelectedDirectory() != null);
       default:
@@ -166,6 +182,8 @@ var DirPaneController =
   doCommand: function(command)
   {
     switch (command) {
+      case "cmd_printcard":
+      case "cmd_printcardpreview":
       case "cmd_selectAll":
         SendCommandToResultsPane(command);
         break;
@@ -176,7 +194,7 @@ var DirPaneController =
         break;
       case "button_edit":
         AbEditSelectedDirectory();
-        break;
+        break;       
     }
   },
 
@@ -199,7 +217,7 @@ function SendCommandToResultsPane(command)
 
 function AbEditSelectedDirectory()
 {
-  if (dirTree.treeBoxObject.selection.count == 1) {
+  if (dirTree.view.selection.count == 1) {
     var selecteduri = GetSelectedDirectory();
     var directory = GetDirectoryFromURI(selecteduri);
     if (directory.isMailList) {
@@ -582,15 +600,6 @@ function DirPaneClick(event)
     event.preventBubble();
     return;
   }
-
-  var searchInput = document.getElementById("searchInput");
-  // if there is a searchInput element, and it's not blank 
-  // then we need to act like the user cleared the
-  // search text
-  if (searchInput && searchInput.value) {
-    searchInput.value = "";
-    onEnterInSearchBar();
-  }
 }
 
 function DirPaneDoubleClick(event)
@@ -599,21 +608,24 @@ function DirPaneDoubleClick(event)
   if (event.button != 0)
     return;
 
-  var row = {}, colID = {}, childElt = {};
-  dirTree.treeBoxObject.getCellAt(event.clientX, event.clientY, row, colID, childElt);
-  if (row.value == -1 || row.value > dirTree.view.rowCount-1) {
+  var row = dirTree.treeBoxObject.getRowAt(event.clientX, event.clientY);
+  if (row == -1 || row > dirTree.view.rowCount-1) {
     // double clicking on a non valid row should not open the dir properties dialog
     return;
   }
 
-  if (dirTree && dirTree.treeBoxObject.selection && dirTree.treeBoxObject.selection.count == 1)
+  if (dirTree && dirTree.view.selection && dirTree.view.selection.count == 1)
     AbEditSelectedDirectory();
 }
 
 function DirPaneSelectionChange()
 {
-  if (dirTree && dirTree.treeBoxObject.selection && dirTree.treeBoxObject.selection.count == 1)
+  // clear out the search box when changing folders...
+  onClearSearch();
+  if (dirTree && dirTree.view.selection && dirTree.view.selection.count == 1) {
+    gPreviousDirTreeIndex = dirTree.currentIndex;
     ChangeDirectoryByURI(GetSelectedDirectory());
+  }
 }
 
 function GetAbResultsBoxObject()
@@ -635,20 +647,32 @@ function CloseAbView()
   }
 }
 
-function SetAbView(uri, sortColumn, sortDirection)
+function SetAbView(uri, searchView, sortColumn, sortDirection)
 {
-  CloseAbView();
-
-  if (!sortColumn)
-    sortColumn = kDefaultSortColumn;
-
-  if (!sortDirection)
-    sortDirection = kDefaultAscending;
-
-  gAbView = Components.classes["@mozilla.org/addressbook/abview;1"].createInstance(Components.interfaces.nsIAbView);
-
-  var actualSortColumn = gAbView.init(uri, GetAbViewListener(), sortColumn, sortDirection);
+  var actualSortColumn;
   
+  // make sure sortColumn and sortDirection have non null values before calling gAbView.init
+  if (!sortColumn)
+		sortColumn = kDefaultSortColumn;
+
+	if (!sortDirection)
+		sortDirection = kDefaultAscending;
+
+  if (gAbView && gCurDirectory == GetSelectedDirectory())
+  {
+    // re-init the view
+    actualSortColumn = gAbView.init(uri, searchView, GetAbViewListener(), sortColumn, sortDirection);
+  }
+  else
+  {
+	  CloseAbView();
+
+		gCurDirectory = GetSelectedDirectory();
+	  gAbView = Components.classes["@mozilla.org/addressbook/abview;1"].createInstance(Components.interfaces.nsIAbView);
+
+		actualSortColumn = gAbView.init(uri, searchView, GetAbViewListener(), sortColumn, sortDirection);
+  }
+
   var boxObject = GetAbResultsBoxObject();
   boxObject.view = gAbView.QueryInterface(Components.interfaces.nsITreeView);
 
@@ -683,7 +707,7 @@ function ChangeDirectoryByURI(uri)
   var sortColumn = gAbResultsTree.getAttribute("sortCol");
   var sortDirection = document.getElementById(sortColumn).getAttribute("sortDirection");
   
-  var actualSortColumn = SetAbView(uri, sortColumn, sortDirection);
+  var actualSortColumn = SetAbView(uri, false, sortColumn, sortDirection);
 
   UpdateSortIndicators(actualSortColumn, sortDirection);
   
@@ -900,6 +924,9 @@ function onAbSearchKeyPress(event)
     
 function onAbSearchInput(returnKeyHit)
 {
+  if (gSearchInput.showingSearchCriteria && !(returnKeyHit && gSearchInput.value == ""))
+    return;
+
   SearchInputChanged();
 
   if (gSearchTimer) {
@@ -940,6 +967,57 @@ function AbSwapFirstNameLastName()
     gAbView.swapFirstNameLastName();
 }
 
+
+function onSearchInputFocus(event)
+{
+  // search bar has focus, ...clear the showing search criteria flag
+  if (gSearchInput.showingSearchCriteria)
+  {
+    gSearchInput.value = "";
+    gSearchInput.showingSearchCriteria = false;
+  }
+
+  gSearchInput.select();
+}
+
+// sets focus into the quick search box
+function QuickSearchFocus()
+{
+  gSearchInput.focus();
+}
+
+function onSearchInputBlur(event)
+{ 
+//  if (gQuickSearchFocusEl && gQuickSearchFocusEl.id == 'searchInput') // ignore the blur if we are in the middle of processing the clear button
+//    return;
+
+  if (!gSearchInput.value)
+    gSearchInput.showingSearchCriteria = true;
+    
+  if (gSearchInput.showingSearchCriteria)
+    gSearchInput.setSearchCriteriaText();
+}
+
+var gQuickSearchFocusEl = null; 
+
+function onClearSearch()
+{
+  if (!gSearchInput.showingSearchCriteria) // ignore the text box value if it's just showing the search criteria string
+  {
+//     gQuickSearchFocusEl = gLastFocusedElement;  //save of the last focused element so that focus can be restored
+     onAbClearSearch();
+     // this needs to be on a timer otherwise we end up messing up the focus while the Search("") is still happening
+     setTimeout("restoreSearchFocusAfterClear();", 0); 
+  }
+}
+
+function restoreSearchFocusAfterClear()
+{
+//  gQuickSearchFocusEl.focus();
+  gSearchInput.clearButtonHidden = 'true';
+  gQuickSearchFocusEl = null;
+}
+
 var gIsOffline;
 var gSessionAdded;
 var gCurrentAutocompleteDirectory;
