@@ -1,3 +1,4 @@
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/mail3PaneWindowCommands.js"
 
 var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
 var gMessengerBundle = document.getElementById("bundle_messenger");
@@ -40,7 +41,7 @@ var FolderPaneController =
       var folderTree = GetFolderTree();
       var startIndex = {};
       var endIndex = {};
-      folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+      folderTree.view.selection.getRangeAt(0, startIndex, endIndex);
       if (startIndex.value >= 0) {
         var canDeleteThisFolder;
 				var specialFolder = null;
@@ -94,11 +95,6 @@ var FolderPaneController =
 	
 	onEvent: function(event)
 	{
-		// on blur events set the menu item texts back to the normal values
-		if ( event == 'blur' )
-        {
-			goSetMenuValue('cmd_delete', 'valueDefault');
-        }
 	}
 };
 
@@ -137,6 +133,7 @@ var DefaultController =
 			case "cmd_previousMsg":
 			case "cmd_previousUnreadMsg":
 			case "cmd_previousFlaggedMsg":
+      case "cmd_goStartPage":
 			case "cmd_viewAllMsgs":
 			case "cmd_viewUnreadMsgs":
       case "cmd_viewThreadsWithUnread":
@@ -175,6 +172,7 @@ var DefaultController =
 			case "cmd_markAsFlagged":
 			case "cmd_markAsJunk":
 			case "cmd_markAsNotJunk":
+      case "cmd_recalculateJunkScore":
       case "cmd_applyFilters":
       case "cmd_runJunkControls":
       case "cmd_deleteJunk":
@@ -188,7 +186,6 @@ var DefaultController =
 			case "cmd_file":
 			case "cmd_emptyTrash":
 			case "cmd_compactFolder":
-			case "cmd_sortByThread":
   	  case "cmd_settingsOffline":
       case "cmd_close":
       case "cmd_selectAll":
@@ -236,23 +233,20 @@ var DefaultController =
           gDBView.getCommandStatus(nsMsgViewCommandType.junk, enabled, checkStatus);
         return enabled.value;
       case "cmd_killThread":
-        return GetNumSelectedMessages() == 1;
+        return GetNumSelectedMessages() > 0;
       case "cmd_watchThread":
-        if ((GetNumSelectedMessages() == 1) && gDBView)
+        if (gDBView)
           gDBView.getCommandStatus(nsMsgViewCommandType.toggleThreadWatched, enabled, checkStatus);
         return enabled.value;
       case "cmd_createFilterFromPopup":
+      case "cmd_createFilterFromMenu":
         var loadedFolder = GetLoadedMsgFolder();
         if (!(loadedFolder && loadedFolder.server.canHaveFilters))
-          return false;
-      case "cmd_createFilterFromMenu":
-        loadedFolder = GetLoadedMsgFolder();
-        if (!(loadedFolder && loadedFolder.server.canHaveFilters) || !(IsMessageDisplayedInMessagePane()))
-          return false;
+          return false;   // else fall thru
       case "cmd_saveAsFile":
       case "cmd_saveAsTemplate":
-	      if ( GetNumSelectedMessages() > 1)
-          return false;
+        if (GetNumSelectedMessages() > 1)
+          return false;   // else fall thru
       case "cmd_reply":
       case "button_reply":
       case "cmd_replySender":
@@ -269,12 +263,12 @@ var DefaultController =
       case "cmd_print":
       case "cmd_viewPageSource":
       case "cmd_reload":
-	      if ( GetNumSelectedMessages() > 0)
+        if (GetNumSelectedMessages() > 0)
         {
           if (gDBView)
           {
-             gDBView.getCommandStatus(nsMsgViewCommandType.cmdRequiringMsgBody, enabled, checkStatus);
-              return enabled.value;
+            gDBView.getCommandStatus(nsMsgViewCommandType.cmdRequiringMsgBody, enabled, checkStatus);
+            return enabled.value;
           }
         }
         return false;
@@ -293,6 +287,7 @@ var DefaultController =
         return (GetNumSelectedMessages() > 0 );
       case "cmd_markAsJunk":
       case "cmd_markAsNotJunk":
+      case "cmd_recalculateJunkScore":
         // can't do news on junk yet.
         return (GetNumSelectedMessages() > 0 && !isNewsURI(GetFirstSelectedMessage()));
       case "cmd_applyFilters":
@@ -326,6 +321,8 @@ var DefaultController =
       case "cmd_previousMsg":
       case "cmd_previousUnreadMsg":
         return IsViewNavigationItemEnabled();
+      case "cmd_goStartPage":
+        return pref.getBoolPref("mailnews.start_page.enabled") && !IsMessagePaneCollapsed();
       case "cmd_markAllRead":
       case "cmd_markReadByDate":
         return IsFolderSelected();
@@ -350,7 +347,6 @@ var DefaultController =
       case "cmd_previousFlaggedMsg":
         return IsViewNavigationItemEnabled();
       case "cmd_viewAllMsgs":
-      case "cmd_sortByThread":
       case "cmd_viewUnreadMsgs":
       case "cmd_viewThreadsWithUnread":
       case "cmd_viewWatchedThreadsWithUnread":
@@ -449,20 +445,14 @@ var DefaultController =
 			case "cmd_delete":
          // if the user deletes a message before its mark as read timer goes off, we should mark it as read
          // this ensures that we clear the biff indicator from the system tray when the user deletes the new message
-        if (gMarkViewedMessageAsReadTimer) 
-        {
+        if (gMarkViewedMessageAsReadTimer)
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteMsg);
 				break;
 			case "cmd_shiftDelete":
         if (gMarkViewedMessageAsReadTimer)
-        {
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteNoTrash);
 				break;
@@ -496,9 +486,10 @@ var DefaultController =
 			case "cmd_previousFlaggedMsg":
 				MsgPreviousFlaggedMessage();
 				break;
-			case "cmd_sortByThread":
-				MsgSortByThread();
-				break;
+      case "cmd_goStartPage":
+        HideMessageHeaderPane();
+        loadStartPage();
+        break;
 			case "cmd_viewAllMsgs":
       case "cmd_viewThreadsWithUnread":
       case "cmd_viewWatchedThreadsWithUnread":
@@ -603,6 +594,9 @@ var DefaultController =
 			case "cmd_markAsNotJunk":
         JunkSelectedMessages(false);
 				return;
+      case "cmd_recalculateJunkScore":
+        analyzeMessagesForJunk();
+        return;
       case "cmd_applyFilters":
         MsgApplyFilters(null);
         return;
@@ -669,7 +663,6 @@ var DefaultController =
 		// on blur events set the menu item texts back to the normal values
 		if ( event == 'blur' )
         {
-			goSetMenuValue('cmd_delete', 'valueDefault');
             goSetMenuValue('cmd_undo', 'valueDefault');
             goSetMenuValue('cmd_redo', 'valueDefault');
         }
@@ -799,7 +792,7 @@ function IsSendUnsentMsgsEnabled(folderResource)
 function IsRenameFolderEnabled()
 {
     var folderTree = GetFolderTree();
-    var selection = folderTree.treeBoxObject.selection;
+    var selection = folderTree.view.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
@@ -848,7 +841,7 @@ function IsPropertiesEnabled(command)
    if (IsFakeAccount())
      return false;
 
-   var selection = folderTree.treeBoxObject.selection;
+   var selection = folderTree.view.selection;
    return (selection.count == 1);
 }
 
@@ -860,7 +853,7 @@ function IsViewNavigationItemEnabled()
 function IsFolderSelected()
 {
     var folderTree = GetFolderTree();
-    var selection = folderTree.treeBoxObject.selection;
+    var selection = folderTree.view.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
@@ -889,6 +882,15 @@ function MsgDeleteFolder()
         var specialFolder = GetFolderAttribute(folderTree, folderResource, "SpecialFolder");
         if (specialFolder != "Inbox" && specialFolder != "Trash")
         {
+            var folder = selectedFolder.QueryInterface(Components.interfaces.nsIMsgFolder);
+            if (folder.flags & MSG_FOLDER_FLAG_VIRTUAL)
+            {
+                if (gCurrentVirtualFolderUri == folderResource.Value)
+                  gCurrentVirtualFolderUri = null;
+                var parentResource = selectedFolder.parent.QueryInterface(Components.interfaces.nsIRDFResource);
+                messenger.DeleteFolders(GetFolderDatasource(), parentResource, folderResource);
+                continue;
+            }
             var protocolInfo = Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + selectedFolder.server.type].getService(Components.interfaces.nsIMsgProtocolInfo);
 
             // do not allow deletion of special folders on imap accounts
@@ -1007,7 +1009,8 @@ function SearchBarToggled()
   }
 
   for (var currentNode = top.document.commandDispatcher.focusedElement; currentNode; currentNode = currentNode.parentNode) {
-    if (currentNode.getAttribute("hidden") == "true") {
+    // But skip the last node, which is a XULDocument.
+    if ((currentNode instanceof XULElement) && currentNode.hidden) {
       SetFocusThreadPane();
       return;
     }
