@@ -1,41 +1,28 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
- * The contents of this file are subject to the Netscape Public
- * License Version 1.1 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of
- * the License at http://www.mozilla.org/NPL/
- * 
- * Software distributed under the License is distributed on an "AS
- * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
- * implied. See the License for the specific language governing
- * rights and limitations under the License.
- * 
- * The Original Code is Mozilla Communicator client code, released
- * March 31, 1998.
- * 
- * The Initial Developer of the Original Code is Netscape
- * Communications Corporation. Portions created by Netscape are
- * Copyright (C) 1998-1999 Netscape Communications Corporation. All
- * Rights Reserved.
- */
-
+//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/mailCommands.js"
 
 function DoRDFCommand(dataSource, command, srcArray, argumentArray)
 {
 	var commandResource = RDF.GetResource(command);
 	if(commandResource) {
-      try {
-		dataSource.DoCommand(srcArray, commandResource, argumentArray);
-      }
-      catch(e) { 
-        if (command == "http://home.netscape.com/NC-rdf#NewFolder") {
-          throw(e); // so that the dialog does not automatically close.
-        }
-        dump("Exception : In mail commands\n");
-      }
+    try {
+      if (!argumentArray)
+        argumentArray = Components.classes["@mozilla.org/supports-array;1"]
+                        .createInstance(Components.interfaces.nsISupportsArray);
+
+      if (argumentArray)
+        argumentArray.AppendElement(msgWindow);
+		  dataSource.DoCommand(srcArray, commandResource, argumentArray);
     }
+    catch(e) { 
+      if (command == "http://home.netscape.com/NC-rdf#NewFolder") {
+        throw(e); // so that the dialog does not automatically close.
+      }
+      dump("Exception : In mail commands" + e + "\n");
+    }
+  }
 }
 
-function GetNewMessages(selectedFolders, compositeDataSource)
+function GetNewMessages(selectedFolders, server, compositeDataSource)
 {
 	var numFolders = selectedFolders.length;
 	if(numFolders > 0)
@@ -47,9 +34,7 @@ function GetNewMessages(selectedFolders, compositeDataSource)
 		{
 			var nsIMsgFolder = Components.interfaces.nsIMsgFolder;
 			msgFolder.biffState = nsIMsgFolder.nsMsgBiffState_NoMail;
-
-			if (msgFolder.hasNewMessages)
-				msgFolder.clearNewMessages();
+			msgFolder.clearNewMessages();
 		}
 		
 		if(compositeDataSource)
@@ -57,8 +42,10 @@ function GetNewMessages(selectedFolders, compositeDataSource)
 			var folderResource = msgFolder.QueryInterface(Components.interfaces.nsIRDFResource);
 		    var folderArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
 			folderArray.AppendElement(folderResource);
+		  var serverArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
+      serverArray.AppendElement(server);
 
-			DoRDFCommand(compositeDataSource, "http://home.netscape.com/NC-rdf#GetNewMessages", folderArray, null);
+			DoRDFCommand(compositeDataSource, "http://home.netscape.com/NC-rdf#GetNewMessages", folderArray, serverArray);
 		}
 	}
 	else {
@@ -70,13 +57,17 @@ function getBestIdentity(identities, optionalHint)
 {
   var identity = null;
 
+  try
+  {
   // if we have more than one identity and a hint to help us pick one
   if (identities.Count() > 1 && optionalHint) {
+    // normalize case on the optional hint to improve our chances of finding a match
+    optionalHint = optionalHint.toLowerCase();
     // iterate over all of the identities
     var tempID;
     for (id = 0; id < identities.Count(); id++) { 
       tempID = identities.GetElementAt(id).QueryInterface(Components.interfaces.nsIMsgIdentity);
-      if (optionalHint.search(tempID.email) >= 0) {
+      if (optionalHint.indexOf(tempID.email.toLowerCase()) >= 0) {
         identity = tempID;
         break;
       }
@@ -97,13 +88,15 @@ function getBestIdentity(identities, optionalHint)
         // extract out the partial domain
         var start = tempID.email.lastIndexOf("@"); // be sure to include the @ sign in our search to reduce the risk of false positives
   
-        if (optionalHint.search(tempID.email.slice(start, tempID.email.length)) >= 0) {
+        if (optionalHint.search(tempID.email.slice(start, tempID.email.length).toLowerCase()) >= 0) {
           identity = tempID;
           break;
         }
       }
     }
   }
+  }
+  catch (ex) {dump (ex + "\n");}
 
   // still no matches? Give up and pick the first one like we used to.
   if (!identity)
@@ -120,7 +113,7 @@ function getIdentityForServer(server, optionalHint)
         var identities = accountManager.GetIdentitiesForServer(server);
         // dump("identities = " + identities + "\n");
         // just get the first one
-        if (identities.Count() > 0 ) {
+        if (identities.Count() > 0 ) { 
           identity = getBestIdentity(identities, optionalHint);
         }
     }
@@ -138,108 +131,119 @@ function GetNextNMessages(folder)
 	}
 }
 
+
 // type is a nsIMsgCompType and format is a nsIMsgCompFormat
 function ComposeMessage(type, format, folder, messageArray) 
 {
-	var msgComposeType = Components.interfaces.nsIMsgCompType;
-	var identity = null;
-	var newsgroup = null;
-	var server;
+  var msgComposeType = Components.interfaces.nsIMsgCompType;
+  var identity = null;
+  var newsgroup = null;
+  var server;
 
-	//dump("ComposeMessage folder="+folder+"\n");
-	try 
-	{
-		if(folder)
-		{
-			// get the incoming server associated with this uri
-			server = folder.server;
+  //dump("ComposeMessage folder="+folder+"\n");
+  try 
+  {
+    if (folder)
+    {
+      // get the incoming server associated with this uri
+      server = folder.server;
 
-			// if they hit new or reply and they are reading a newsgroup
-			// turn this into a new post or a reply to group.
+      // if they hit new or reply and they are reading a newsgroup
+      // turn this into a new post or a reply to group.
       if (!folder.isServer && server.type == "nntp" && type == msgComposeType.New)
-			{
+      {
         type = msgComposeType.NewsPost;
         newsgroup = folder.folderURL;
-			}
+      }
 
-      // 
       identity = getIdentityForServer(server);
       // dump("identity = " + identity + "\n");
-		}
-	}
-	catch (ex) 
-	{
-        	dump("failed to get an identity to pre-select: " + ex + "\n");
-	}
+    }
+  }
+  catch (ex) 
+  {
+    dump("failed to get an identity to pre-select: " + ex + "\n");
+  }
 
-	//dump("\nComposeMessage from XUL: " + identity + "\n");
-	var uri = null;
+  //dump("\nComposeMessage from XUL: " + identity + "\n");
+  var uri = null;
 
-	if (! msgComposeService)
-	{
-		dump("### msgComposeService is invalid\n");
-		return;
-	}
+  if (! msgComposeService)
+  {
+    dump("### msgComposeService is invalid\n");
+    return;
+  }
 	
-	if (type == msgComposeType.New) //new message
-	{
-		//dump("OpenComposeWindow with " + identity + "\n");
+  if (type == msgComposeType.New) //new message
+  {
+    //dump("OpenComposeWindow with " + identity + "\n");
 
     // if the addressbook sidebar panel is open and has focus, get
     // the selected addresses from it
     if (document.commandDispatcher.focusedWindow.document.documentElement.hasAttribute("selectedaddresses"))
       NewMessageToSelectedAddresses(type, format, identity);
-
     else
       msgComposeService.OpenComposeWindow(null, null, type, format, identity, msgWindow);
-		return;
-	}
+    return;
+  }
   else if (type == msgComposeType.NewsPost) 
-	{
-		//dump("OpenComposeWindow with " + identity + " and " + newsgroup + "\n");
-		msgComposeService.OpenComposeWindow(null, newsgroup, type, format, identity, msgWindow);
-		return;
-	}
+  {
+    //dump("OpenComposeWindow with " + identity + " and " + newsgroup + "\n");
+    msgComposeService.OpenComposeWindow(null, newsgroup, type, format, identity, msgWindow);
+    return;
+  }
 		
-	messenger.SetWindow(window, msgWindow);
-			
-	var object = null;
-	
-	if (messageArray && messageArray.length > 0)
-	{
-		uri = "";
-		for (var i = 0; i < messageArray.length; i ++)
-		{	
-			var messageUri = messageArray[i];
+  messenger.SetWindow(window, msgWindow);
+		  
+  var object = null;
+  
+  if (messageArray && messageArray.length > 0)
+  {
+    uri = "";
+    for (var i = 0; i < messageArray.length; i ++)
+    {	
+      var messageUri = messageArray[i];
 
-      var hdr = messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
+      var hdr = messenger.msgHdrFromURI(messageUri);
+      // if we treat reply from sent specially, do we check for that folder flag here?
       var hintForIdentity = (type == msgComposeType.Template) ? hdr.author : hdr.recipients + hdr.ccList;
+      var accountKey = hdr.accountKey;
+      if (accountKey.length > 0)
+      {
+        var account = accountManager.getAccount(accountKey);
+        if (account)
+          server = account.incomingServer;
+      }
 
       if (server)
         identity = getIdentityForServer(server, hintForIdentity);
 
-			if (type == msgComposeType.Reply || type == msgComposeType.ReplyAll || type == msgComposeType.ForwardInline ||
-				type == msgComposeType.ReplyToGroup || type == msgComposeType.ReplyToSender || 
-				type == msgComposeType.ReplyToSenderAndGroup ||
-				type == msgComposeType.Template || type == msgComposeType.Draft)
-			{
-				msgComposeService.OpenComposeWindow(null, messageUri, type, format, identity, msgWindow);
+      var messageID = hdr.messageId;
+      var messageIDScheme = messageID.split(":")[0];
+      if ((messageIDScheme == 'http' || messageIDScheme == 'https') &&  "openComposeWindowForRSSArticle" in this) 
+        openComposeWindowForRSSArticle(messageID, hdr, type); 
+      else if (type == msgComposeType.Reply || type == msgComposeType.ReplyAll || type == msgComposeType.ForwardInline ||
+                type == msgComposeType.ReplyToGroup || type == msgComposeType.ReplyToSender || 
+                type == msgComposeType.ReplyToSenderAndGroup ||
+                type == msgComposeType.Template || type == msgComposeType.Draft)
+      {
+        msgComposeService.OpenComposeWindow(null, messageUri, type, format, identity, msgWindow);
         //limit the number of new compose windows to 8. Why 8? I like that number :-)
         if (i == 7)
           break;
-			}
-			else
-			{
-				if (i) 
-					uri += ","
-				uri += messageUri;
-			}
-		}
-		if (type == msgComposeType.ForwardAsAttachment)
-			msgComposeService.OpenComposeWindow(null, uri, type, format, identity, msgWindow);
-	}
-	else
-		dump("### nodeList is invalid\n");
+      }
+      else
+      {
+        if (i) 
+          uri += ","
+        uri += messageUri;
+      }
+    }
+    if (type == msgComposeType.ForwardAsAttachment && uri)
+      msgComposeService.OpenComposeWindow(null, uri, type, format, identity, msgWindow);
+  }
+  else
+    dump("### nodeList is invalid\n");
 }
 
 function NewMessageToSelectedAddresses(type, format, identity) {
@@ -387,7 +391,7 @@ function SaveAsFile(uri)
     var filename = null;
     try {
       var subject = messenger.messageServiceFromURI(uri)
-                             .messageURIToMsgHdr(uri).subject;
+                             .messageURIToMsgHdr(uri).mime2DecodedSubject;
       filename = GenerateValidFilename(subject, ".eml");
     }
     catch (ex) {}
@@ -405,6 +409,7 @@ function SaveAsTemplate(uri, folder)
 
 function MarkSelectedMessagesRead(markRead)
 {
+  ClearPendingReadTimer();
   gDBView.doCommand(markRead ? nsMsgViewCommandType.markMessagesRead : nsMsgViewCommandType.markMessagesUnread);
 }
 
@@ -455,7 +460,7 @@ function ViewPageSource(messages)
             // Now, we need to get a URL from a URI
             var url = mailSession.ConvertMsgURIToMsgURL(messages[i], msgWindow);
 
-            window.openDialog( "chrome://navigator/content/viewSource.xul",
+            window.openDialog( "chrome://global/content/viewSource.xul",
                                "_blank",
                                "scrollbars,resizable,chrome,dialog=no",
                                url,
@@ -585,9 +590,8 @@ function analyze(aMsgHdr, aNextFunction)
     {
       var whiteListDirectory = RDF.GetResource(spamSettings.whiteListAbURI).QueryInterface(Components.interfaces.nsIAbMDBDirectory);
       var headerParser = Components.classes["@mozilla.org/messenger/headerparser;1"].getService(Components.interfaces.nsIMsgHeaderParser);
-      var authorEmailAddress = new Object;
-      headerParser.extractHeaderAddressMailboxes(null, aMsgHdr.author, authorEmailAddress);
-      if (whiteListDirectory.hasCardForEmailAddress(authorEmailAddress.value))
+      var authorEmailAddress = headerParser.extractHeaderAddressMailboxes(null, aMsgHdr.author);
+      if (whiteListDirectory.hasCardForEmailAddress(authorEmailAddress))
       {
         // skip over this message, like we do on incoming mail
         // the difference is it could be marked as junk from previous analysis
@@ -617,7 +621,11 @@ function analyzeFolderForJunk()
 
   var messages = new Array(count)
   for (var i = 0; i < count; i++) {
-    messages[i] = view.getURIForViewIndex(i);
+    try
+    {
+      messages[i] = view.getURIForViewIndex(i);
+    }
+    catch (ex) {} // blow off errors here - dummy headers will fail
   }
   analyzeMessages(messages);
 }
@@ -631,33 +639,38 @@ function analyzeMessagesForJunk()
 
 function analyzeMessages(messages)
 {
-    function processNext()
+  function processNext()
+  {
+    if (counter < messages.length) 
     {
-        if (counter < messages.length) {
-            var messageUri = messages[counter];
-            var message = messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
-            ++counter;
-            analyze(message, processNext);
-        }
-        else {
-            dump('[bayesian filter message analysis complete.]\n');
-            gJunkmailComponent.endBatch();
-            performActionOnJunkMsgs();
-        }
-    }
+      var messageUri = messages[counter];
+      var message = messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
+      ++counter;
+      analyze(message, processNext);
+     }
+     else 
+       performActionOnJunkMsgs();
+  }
 
-    getJunkmailComponent();
-    var counter = 0;
-    gJunkmailComponent.startBatch();
-    dump('[bayesian filter message analysis begins.]\n');
-    processNext();
+  getJunkmailComponent();
+  var counter = 0;
+  processNext();
 }
 
 function JunkSelectedMessages(setAsJunk)
 {
-    MsgJunkMailInfo(true);
-    gDBView.doCommand(setAsJunk ? nsMsgViewCommandType.junk
-                      : nsMsgViewCommandType.unjunk);
+  MsgJunkMailInfo(true);
+
+  // When the user explicitly marks a message as junk, he doesn't want it to
+  // stay unread (even if he does want that for automatically-classified ones),
+  // so we always mark as read here (pref-independent, see bug 220933).
+  // Note that this behaviour should match the one in the back end for marking
+  // as junk via clicking the 'junk' column.
+  if (setAsJunk)
+    MarkSelectedMessagesRead(true);
+
+  gDBView.doCommand(setAsJunk ? nsMsgViewCommandType.junk
+                              : nsMsgViewCommandType.unjunk);
 }
 
 function deleteJunkInFolder()
@@ -678,9 +691,13 @@ function deleteJunkInFolder()
   var clearedSelection = false;
   
   // select the junk messages
+  var messageUri;
   for (var i = 0; i < count; i++) 
   {
-    var messageUri = view.getURIForViewIndex(i);
+    try {
+      messageUri = view.getURIForViewIndex(i);
+    }
+    catch (ex) {continue;} // blow off errors for dummy rows
     var msgHdr = messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
     var junkScore = msgHdr.getStringProperty("junkscore"); 
     var isJunk = ((junkScore != "") && (junkScore != "0"));
