@@ -1,3 +1,4 @@
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/mailWindow.js"
 
 //This file stores variables common to mail windows
 var messengerContractID        = "@mozilla.org/messenger;1";
@@ -86,7 +87,6 @@ function OnMailWindowUnload()
 
 
   msgWindow.closeWindow();
-
 }
 
 function CreateMessenger()
@@ -107,7 +107,12 @@ function CreateMailWindowGlobals()
   // set the JS implementation of status feedback before creating the c++ one..
   window.MsgStatusFeedback = new nsMsgStatusFeedback();
   // double register the status feedback object as the xul browser window implementation
-  window.XULBrowserWindow = window.MsgStatusFeedback;
+  window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+        .getInterface(Components.interfaces.nsIWebNavigation)
+        .QueryInterface(Components.interfaces.nsIDocShellTreeItem).treeOwner
+        .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+        .getInterface(Components.interfaces.nsIXULWindow)
+        .XULBrowserWindow = window.MsgStatusFeedback;
 
   statusFeedback           = Components.classes[statusFeedbackContractID].createInstance();
   statusFeedback = statusFeedback.QueryInterface(Components.interfaces.nsIMsgStatusFeedback);
@@ -159,7 +164,7 @@ function CreateMailWindowGlobals()
 
   //Create datasources
   accountManagerDataSource = Components.classes[accountManagerDSContractID].createInstance();
-  folderDataSource         = Components.classes[folderDSContractID].createInstance();
+  folderDataSource         = Components.classes[folderDSContractID].getService();
 
   accountCentralBox = document.getElementById("accountCentralBox");
   gSearchBox = document.getElementById("searchBox");
@@ -173,6 +178,7 @@ function InitMsgWindow()
   msgWindow.SetDOMWindow(window);
   mailSession.AddMsgWindow(msgWindow);
   document.getElementById("messagepane").docShell.allowAuth = false;
+  msgWindow.rootDocShell.allowAuth = true; 
 }
 
 function AddDataSources()
@@ -234,6 +240,7 @@ nsMsgStatusFeedback.prototype =
   progressMeterContainer : null,
   pendingStartRequests : 0,
   meteorsSpinning : false,
+  myDefaultStatus : null,
   progressMeterVisible : false,
 
   ensureStatusFields : function()
@@ -248,13 +255,21 @@ nsMsgStatusFeedback.prototype =
   // nsIXULBrowserWindow implementation
   setJSStatus : function(status)
     {
+      if (status.length > 0)
+        this.showStatusString(status);
     },
   setJSDefaultStatus : function(status)
     {
+      if (status.length > 0)
+      {
+        this.myDefaultStatus = status;
+        this.statusTextFld.label = status;
+      }
     },
   setOverLink : function(link)
     {
-      this.showStatusString(link);
+      this.ensureStatusFields();
+      this.statusTextFld.label = link;
     },
   QueryInterface : function(iid)
     {
@@ -269,8 +284,10 @@ nsMsgStatusFeedback.prototype =
   showStatusString : function(statusText)
     {
       this.ensureStatusFields();
-      if ( statusText == "" )
-        statusText = defaultStatus;
+      if ( !statusText.length )
+        statusText = this.myDefaultStatus;
+      else
+        this.myDefaultStatus = "";
       this.statusTextFld.label = statusText;
   },
   _startMeteors : function()
@@ -321,9 +338,7 @@ nsMsgStatusFeedback.prototype =
         gTimelineService.resetTimer("FolderLoading");
       }
       this.ensureStatusFields();
-      var msg = gMessengerBundle.getString("documentDone");
-      this.showStatusString(msg);
-      defaultStatus = msg;
+      this.showStatusString(defaultStatus);
       
       // stop the throbber
       if (this.throbber)
@@ -433,80 +448,125 @@ function StopUrls()
   msgWindow.StopUrls();
 }
 
-function loadStartPage() {
-    try {
-        // collapse the junk bar
-        SetUpJunkBar(null);
+function loadStartPage() 
+{
+  try 
+  {
+    gMessageNotificationBar.clearMsgNotifications();
+    
+    var startpageenabled = pref.getBoolPref("mailnews.start_page.enabled");
+    if (startpageenabled) 
+    {
+      
+      var startpage = pref.getComplexValue("mailnews.start_page.url", Components.interfaces.nsIPrefLocalizedString).data;
 
-        var startpageenabled = pref.getBoolPref("mailnews.start_page.enabled");
+      // Some users have our old default start page
+      // showing up as a user pref instead of a default pref. If this is the case, clear the user pref by hand 
+      // and re-read it again so we get the correct default start page.
+      if (startpage == "chrome://messenger/locale/start.html")
+      {
+        pref.clearUserPref("mailnews.start_page.url");
+        startpage = pref.getComplexValue("mailnews.start_page.url", Components.interfaces.nsIPrefLocalizedString).data;
+      }
 
-        if (startpageenabled) {
-            var startpage = pref.getComplexValue("mailnews.start_page.url",
-                                                 Components.interfaces.nsIPrefLocalizedString).data;
-            if (startpage != "") {
-                // first, clear out the charset setting.
-                messenger.setDisplayCharset("");
-
-                GetMessagePaneFrame().location = startpage;
-                //dump("start message pane with: " + startpage + "\n");
-                ClearMessageSelection();
-            }
-        }
-    }
-    catch (ex) {
-        dump("Error loading start page.\n");
-        return;
+      if (startpage != "") 
+      {
+        GetMessagePaneFrame().location.href = startpage;
+        //dump("start message pane with: " + startpage + "\n");
+        ClearMessageSelection();
+      }
     }
+  }
+  catch (ex) 
+  {
+    dump("Error loading start page.\n");
+    return;
+  }
 }
 
-// Display AccountCentral page when users clicks on the Account Folder.
-// When AccountCentral page need to be shown, we need to hide
-// the box containing threadPane, splitter and messagePane.
-// Load iframe in the AccountCentral box with corresponding page
 function ShowAccountCentral()
+{
+  if (document.getElementById("displayDeck").selectedPanel == accountCentralBox)
+    ShowingAccountCentral(); // force us to reload account central because the user has switched accounts
+  else
+    document.getElementById("displayDeck").selectedPanel = accountCentralBox;
+}
+
+// When AccountCentral is shown via the displayDeck, we need to switch the
+// displayDeck to show the accountCentralBox, collapse all the other
+// UI elements that aren't meaningful for AccountCentral, and finally
+// load the iframe in the AccountCentral box with corresponding page.
+function ShowingAccountCentral()
 {
     try
     {
-    var acctCentralPage = pref.getComplexValue("mailnews.account_central_page.url",
+        var acctCentralPage = pref.getComplexValue("mailnews.account_central_page.url",
                                                Components.interfaces.nsIPrefLocalizedString).data;
         GetMessagePane().collapsed = true;
         document.getElementById("threadpane-splitter").collapsed = true;
         gSearchBox.collapsed = true;
-        GetThreadTree().collapsed = true;
-        document.getElementById("accountCentralBox").collapsed = false;
-    window.frames["accountCentralPane"].location = acctCentralPage;
+
+        window.frames["accountCentralPane"].location.href = acctCentralPage;
+        
         if (!IsFolderPaneCollapsed())
-            GetFolderTree().focus();
-    gAccountCentralLoaded = true;
+            GetFolderTree().focus();        
+
+        gAccountCentralLoaded = true;
     }
     catch (ex)
     {
         dump("Error loading AccountCentral page -> " + ex + "\n");
-        return;
     }
 }
 
-// Display thread and message panes with splitter when user tries
-// to read messages by clicking on msgfolders. Hide AccountCentral
-// box and display message box.
-function HideAccountCentral()
+function HidingAccountCentral()
 {
     try
     {
-        window.frames["accountCentralPane"].location = "about:blank";
-        document.getElementById("accountCentralBox").collapsed = true;
-        GetThreadTree().collapsed = false;
-        gSearchBox.collapsed = false;
-        var threadPaneSplitter = document.getElementById("threadpane-splitter");
-        threadPaneSplitter.collapsed = false;
-        GetMessagePane().collapsed = threadPaneSplitter.getAttribute("state") == "collapsed";
-        gAccountCentralLoaded = false;
+        window.frames["accountCentralPane"].location.href = "about:blank";
     }
     catch (ex)
     {
         dump("Error hiding AccountCentral page -> " + ex + "\n");
-        return;
     }
+    gAccountCentralLoaded = false;
+}
+
+function ShowThreadPane()
+{
+    document.getElementById("displayDeck").selectedPanel = 
+        document.getElementById("threadPaneBox");
+}
+
+function ShowingThreadPane()
+{
+    gSearchBox.collapsed = false;
+    var threadPaneSplitter = document.getElementById("threadpane-splitter");
+    threadPaneSplitter.collapsed = false;
+    GetMessagePane().collapsed =
+        (threadPaneSplitter.getAttribute("state") == "collapsed");
+}
+
+function HidingThreadPane()
+{
+    ClearThreadPane();
+}
+
+function ObserveDisplayDeckChange(event)
+{
+    var deck = document.getElementById("displayDeck");
+    var nowSelected = null;
+    try { nowSelected = deck.selectedPanel.id; } catch (ex) { }
+
+    if (nowSelected == "threadPaneBox")
+        ShowingThreadPane();
+    else
+        HidingThreadPane();
+    
+    if (nowSelected == "accountCentralBox")
+        ShowingAccountCentral();
+    else
+        HidingAccountCentral();
 }
 
 // Given the server, open the twisty and the set the selection
@@ -515,7 +575,7 @@ function HideAccountCentral()
 function OpenInboxForServer(server)
 {
     try {
-        HideAccountCentral();
+        ShowThreadPane();
         var inboxFolder = GetInboxFolder(server);
         SelectFolder(inboxFolder.URI);
 
@@ -523,17 +583,8 @@ function OpenInboxForServer(server)
             if (server.type != "imap")
                 GetMessagesForInboxOnServer(server);
         }
-        else {
-            var option = PromptGetMessagesOffline();
-            if(option == 0) {
-                if (!gOfflineManager) 
-                    GetOfflineMgrService();
-
-                gOfflineManager.goOnline(false /* sendUnsentMessages */, 
-                                         false /* playbackOfflineImapOperations */, 
-                                         msgWindow);
+        else if (DoGetNewMailWhenOffline()) {
                 GetMessagesForInboxOnServer(server);
-            }
         }
     }
     catch (ex) {
