@@ -1,3 +1,4 @@
+//@line 38 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/messageWindow.js"
 
 /* This is where functions related to the standalone message window are kept */
 
@@ -21,41 +22,22 @@ var gNextMessageAfterLoad = null;
 
 // the folderListener object
 var folderListener = {
-  OnItemAdded: function(parentItem, item, view) {},
+  OnItemAdded: function(parentItem, item) {},
 
-  OnItemRemoved: function(parentItem, item, view) {
-    var parentFolderResource = parentItem.QueryInterface(Components.interfaces.nsIRDFResource);
-    if (!parentFolderResource)
+  OnItemRemoved: function(parentItem, item) {
+    if (parentItem.Value != gCurrentFolderUri)
       return;
 
-    var parentURI = parentFolderResource.Value;
-    if (parentURI != gCurrentFolderUri)
-      return;
-
-    var deletedMessageHdr = item.QueryInterface(Components.interfaces.nsIMsgDBHdr);
-    if (extractMsgKeyFromURI() == deletedMessageHdr.messageKey)
+    if (item instanceof Components.interfaces.nsIMsgDBHdr &&
+        extractMsgKeyFromURI() == item.messageKey)
       gCurrentMessageIsDeleted = true;
   },
 
   OnItemPropertyChanged: function(item, property, oldValue, newValue) {},
   OnItemIntPropertyChanged: function(item, property, oldValue, newValue) { 
-    var currentLoadedFolder = GetLoadedMsgFolder();
-    if (!currentLoadedFolder) return;
-    var currentURI = currentLoadedFolder.URI;
-
-    //if we don't have a folder loaded, don't bother.
-    if (currentURI) {
+    if (item.Value == gCurrentFolderUri) {
       if (property.toString() == "TotalMessages" || property.toString() == "TotalUnreadMessages") {
-        var folder = item.QueryInterface(Components.interfaces.nsIMsgFolder);
-        if (folder) {
-          var folderResource = folder.QueryInterface(Components.interfaces.nsIRDFResource); 
-          if (folderResource) {
-            var folderURI = folderResource.Value;
-            if (currentURI == folderURI) {
-              UpdateStandAloneMessageCounts();
-            }
-          }
-        }
+        UpdateStandAloneMessageCounts();
       }      
     }
   },
@@ -190,7 +172,7 @@ function HandleDeleteOrMoveMsgCompleted(folder)
     {
       var nextMstKey = gDBView.getKeyAt(gNextMessageViewIndexAfterDelete);
       if (nextMstKey != nsMsgKey_None) {
-        LoadMessageByMsgKey(nextMstKey);
+        LoadMessageByViewIndex(gNextMessageViewIndexAfterDelete);
       }
       else {
         window.close();
@@ -234,18 +216,19 @@ function OnLoadMessageWindow()
 
 function delayedOnLoadMessageWindow()
 {
-	HideMenus();
+  HideMenus();
+  ShowMenus();
   AddMailOfflineObserver();
-	CreateMailWindowGlobals();
-	CreateMessageWindowGlobals();
-	verifyAccounts(null);
+  CreateMailWindowGlobals();
+  CreateMessageWindowGlobals();
+  verifyAccounts(null);
 
-	InitMsgWindow();
+  InitMsgWindow();
 
-	messenger.SetWindow(window, msgWindow);
-	InitializeDataSources();
-	// FIX ME - later we will be able to use onload from the overlay
-	OnLoadMsgHeaderPane();
+  messenger.SetWindow(window, msgWindow);
+  InitializeDataSources();
+  // FIX ME - later we will be able to use onload from the overlay
+  OnLoadMsgHeaderPane();
 
   try {
     var nsIFolderListener = Components.interfaces.nsIFolderListener;
@@ -259,16 +242,16 @@ function delayedOnLoadMessageWindow()
   var folder = null;
   var messageUri;
   var loadCustomMessage = false;       //set to true when either loading a message/rfc822 attachment or a .eml file
-	if (window.arguments)
-	{
-		if (window.arguments[0])
+  if (window.arguments)
+  {
+    if (window.arguments[0])
     {
       try
       {
         messageUri = window.arguments[0];
         if (messageUri instanceof Components.interfaces.nsIURI)
         {
-          loadCustomMessage = /type=x-message-display/.test(messageUri.spec);
+          loadCustomMessage = /type=application\/x-message-display/.test(messageUri.spec);
           gCurrentMessageUri = messageUri.spec;
           if (messageUri instanceof Components.interfaces.nsIMsgMailNewsUrl)
             folder = messageUri.folder;
@@ -281,20 +264,20 @@ function delayedOnLoadMessageWindow()
       }
 
       if (!gCurrentMessageUri)
-			gCurrentMessageUri = window.arguments[0];
+        gCurrentMessageUri = window.arguments[0];
     }
-		else
-			gCurrentMessageUri = null;
+    else
+      gCurrentMessageUri = null;
 
-		if (window.arguments[1])
-			gCurrentFolderUri = window.arguments[1];
-		else
+    if (window.arguments[1])
+      gCurrentFolderUri = window.arguments[1];
+    else
       gCurrentFolderUri = folder ? folder.URI : null;
 
     if (window.arguments[2])
       originalView = window.arguments[2];      
 
-	}	
+  }	
 
   CreateView(originalView);
   
@@ -313,11 +296,14 @@ function delayedOnLoadMessageWindow()
 function OnLoadMessageWindowDelayed(loadCustomMessage)
 {
   if (loadCustomMessage)
+  {
+    gDBView.suppressMsgDisplay = false;
     gDBView.loadMessageByUrl(gCurrentMessageUri);
+  }
   else
-{
-  var msgKey = extractMsgKeyFromURI(gCurrentMessageUri); 
-  gDBView.loadMessageByMsgKey(msgKey); 
+  {
+    var msgKey = extractMsgKeyFromURI(gCurrentMessageUri); 
+    LoadMessageByViewIndex(gDBView.findIndexFromKey(msgKey, true));
   }
   gNextMessageViewIndexAfterDelete = gDBView.msgToSelectAfterDelete; 
   UpdateStandAloneMessageCounts();
@@ -363,6 +349,13 @@ function CreateView(originalView)
       dbFolderInfo = null;
    }
   }
+  else
+  {
+    // this is a hack to make opening a stand-alone msg window on a 
+    // .eml file work. We use a search view since its much more tolerant
+    // of not having a folder.
+    viewType = nsMsgViewType.eShowSearch;
+  }
 
   // create a db view
   CreateBareDBView(originalView, msgFolder, viewType, viewFlags, sortType, sortOrder); 
@@ -385,17 +378,19 @@ function CreateView(originalView)
 function extractMsgKeyFromURI()
 {
   var msgKey = -1;
-  var msgService = messenger.messageServiceFromURI(gCurrentMessageUri);
-  if (msgService)
-  {
-    var msgHdr = msgService.messageURIToMsgHdr(gCurrentMessageUri);
-    if (msgHdr)
-      msgKey = msgHdr.messageKey;
-  }
-
+  var msgHdr =   messenger.msgHdrFromURI(gCurrentMessageUri);
+  if (msgHdr)
+    msgKey = msgHdr.messageKey;
   return msgKey;
 }
 
+function ShowMenus()
+{
+  var openMail3Pane_menuitem = document.getElementById('tasksMenuMail');
+  if (openMail3Pane_menuitem)
+    openMail3Pane_menuitem.removeAttribute("hidden");
+}
+
 function HideMenus()
 {
 	var message_menuitem=document.getElementById('menu_showMessage');
@@ -499,12 +494,12 @@ function InitializeDataSources()
 
 function GetSelectedMsgFolders()
 {
-	var folderArray = new Array(1);
-	var msgFolder = GetLoadedMsgFolder();
-	if (msgFolder)
-		folderArray[0] = msgFolder;	
+  var folderArray = new Array(1);
+  var msgFolder = GetLoadedMsgFolder();
+  if (msgFolder)
+    folderArray[0] = msgFolder;	
 
-	return folderArray;
+  return folderArray;
 }
 
 function GetFirstSelectedMessage()
@@ -546,10 +541,14 @@ function GetSelectedIndices(dbView)
 
 function GetLoadedMsgFolder()
 {
-	if (gCurrentFolderUri)
-		return RDF.GetResource(gCurrentFolderUri).QueryInterface(Components.interfaces.nsIMsgFolder);
-	else
-    return null;
+  return (gCurrentFolderUri)
+    ? RDF.GetResource(gCurrentFolderUri).QueryInterface(Components.interfaces.nsIMsgFolder)
+    : null;
+}
+
+function GetSelectedFolderURI()
+{
+  return gCurrentFolderUri;
 }
 
 function GetLoadedMessage()
@@ -560,14 +559,14 @@ function GetLoadedMessage()
 //Clear everything related to the current message. called after load start page.
 function ClearMessageSelection()
 {
-	gCurrentMessageUri = null;
-	gCurrentFolderUri = null;
+  gCurrentMessageUri = null;
+  gCurrentFolderUri = null;
   UpdateMailToolbar("clear msg, std alone window");
 }
 
 function GetCompositeDataSource(command)
 {
-	return gCompositeDataSource;	
+  return gCompositeDataSource;	
 }
 
 function SetNextMessageAfterDelete()
@@ -641,7 +640,7 @@ function RerootFolderForStandAlone(uri)
 
 function GetMsgHdrFromUri(messageUri)
 {
-  return messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
+  return messenger.msgHdrFromURI(messageUri);
 }
 
 function SelectMessage(messageUri)
@@ -681,38 +680,27 @@ function MsgDeleteMessageFromMessageWindow(reallyDelete, fromToolbar)
 var MessageWindowController =
 {
    supportsCommand: function(command)
-	{
-		switch ( command )
-		{
-			case "cmd_reply":
-			case "button_reply":
-			case "cmd_replySender":
-			case "cmd_replyGroup":
-			case "cmd_replyall":
-			case "button_replyall":
-			case "cmd_forward":
-			case "button_forward":
-			case "cmd_forwardInline":
-			case "cmd_forwardAttachment":
-			case "cmd_editAsNew":
-			case "cmd_delete":
+  {
+    switch ( command )
+    {
+      case "cmd_delete":
       case "cmd_undo":
       case "cmd_redo":
       case "cmd_killThread":
       case "cmd_watchThread":
-			case "button_delete":
+      case "button_delete":
       case "button_junk":
-			case "cmd_shiftDelete":
-			case "cmd_saveAsFile":
-			case "cmd_saveAsTemplate":
-			case "cmd_viewPageSource":
+      case "cmd_shiftDelete":
+      case "cmd_saveAsFile":
+      case "cmd_saveAsTemplate":
+      case "cmd_viewPageSource":
       case "cmd_getMsgsForAuthAccounts":
       case "button_mark":
-			case "cmd_markAsRead":
-			case "cmd_markAllRead":
-			case "cmd_markThreadAsRead":
+      case "cmd_markAsRead":
+      case "cmd_markAllRead":
+      case "cmd_markThreadAsRead":
       case "cmd_markReadByDate":
-			case "cmd_markAsFlagged":
+      case "cmd_markAsFlagged":
       case "cmd_label0":
       case "cmd_label1":
       case "cmd_label2":
@@ -720,22 +708,35 @@ var MessageWindowController =
       case "cmd_label4":
       case "cmd_label5":
       case "button_file":
-			case "cmd_file":
+      case "cmd_file":
       case "cmd_markAsJunk":
       case "cmd_markAsNotJunk":
+      case "cmd_recalculateJunkScore":
       case "cmd_applyFilters":
       case "cmd_runJunkControls":
       case "cmd_deleteJunk":
-			case "cmd_nextMsg":
+      case "cmd_nextMsg":
       case "button_next":
       case "button_previous":
-			case "cmd_nextUnreadMsg":
-			case "cmd_nextFlaggedMsg":
-			case "cmd_nextUnreadThread":
-			case "cmd_previousMsg":
-			case "cmd_previousUnreadMsg":
-			case "cmd_previousFlaggedMsg":
+      case "cmd_nextUnreadMsg":
+      case "cmd_nextFlaggedMsg":
+      case "cmd_nextUnreadThread":
+      case "cmd_previousMsg":
+      case "cmd_previousUnreadMsg":
+      case "cmd_previousFlaggedMsg":
         return !(gDBView.keyForFirstSelectedMessage == nsMsgKey_None);
+
+      case "cmd_reply":
+      case "button_reply":
+      case "cmd_replySender":
+      case "cmd_replyGroup":
+      case "cmd_replyall":
+      case "button_replyall":
+      case "cmd_forward":
+      case "button_forward":
+      case "cmd_forwardInline":
+      case "cmd_forwardAttachment":
+      case "cmd_editAsNew":
       case "cmd_getNextNMessages":
       case "cmd_find":
       case "cmd_findAgain":
@@ -783,6 +784,7 @@ var MessageWindowController =
         // fall through
       case "cmd_markAsJunk":
 			case "cmd_markAsNotJunk":
+      case "cmd_recalculateJunkScore":
         // can't do junk on news yet
         return (!isNewsURI(gCurrentFolderUri));
 			case "cmd_reply":
@@ -987,6 +989,9 @@ var MessageWindowController =
 			case "cmd_markAsNotJunk":
         JunkSelectedMessages(false);
 				return;
+      case "cmd_recalculateJunkScore":
+        analyzeMessagesForJunk();
+        return;
       case "cmd_label0":
         gDBView.doCommand(nsMsgViewCommandType.label0);
  				return;
@@ -1094,13 +1099,13 @@ function GetDBView()
 
 function LoadMessageByMsgKey(messageKey)
 {
+  LoadMessageByViewIndex(gDBView.findIndexFromKey(messageKey, true));
+}
+
+function LoadMessageByViewIndex(viewIndex)
+{
+  gDBView.loadMessageByViewIndex(viewIndex);
   // we only want to update the toolbar if there was no previous selected message.
   if (nsMsgKey_None == gDBView.keyForFirstSelectedMessage)
-  {
-    gDBView.loadMessageByMsgKey(messageKey);
     UpdateMailToolbar("update toolbar for message Window");
-  }
-  else
-    gDBView.loadMessageByMsgKey(messageKey);
-
 }
