@@ -1,3 +1,4 @@
+//@line 43 "/usr/obj/ports/mozilla-thunderbird-1.5p2/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
 /* This is where functions related to the 3 pane window are kept */
 
@@ -10,6 +11,9 @@ const kStandardPaneConfig = 0;
 const kWidePaneConfig = 1;
 const kVerticalPaneConfig = 2;
 
+// from nsMsgFolderFlags.h
+const MSG_FOLDER_FLAG_ELIDED = 0x10;
+
 var gFolderTree; 
 var gMessagePane;
 var gThreadTree;
@@ -72,32 +76,60 @@ function SelectAndScrollToKey(aMsgKey)
   return true;
 }
 
+// A helper routine called after a folder is loaded to make sure
+// we select and scroll to the correct message (could be the first new message,
+// could be the last displayed message, etc.)
+// returns true if we ended up scrolling to a message
+function ScrollToMessageAfterFolderLoad (folder)
+{
+  var scrolled = ScrollToMessage(nsMsgNavigationType.firstNew, true, false /* selectMessage */);
+  if (!scrolled && folder && pref.getBoolPref("mailnews.remember_selected_message")) 
+  {
+    // if we failed to scroll to a new message,
+    // reselect the last selected message
+    var lastMessageLoaded = folder.lastMessageLoaded;
+    if (lastMessageLoaded != nsMsgKey_None)
+      scrolled = SelectAndScrollToKey(lastMessageLoaded);
+  }
+  
+  if (!scrolled) 
+  {
+    // if we still haven't scrolled,
+    // scroll to the newest, which might be the top or the bottom
+    // depending on our sort order and sort type
+    if (gDBView.sortOrder == nsMsgViewSortOrder.ascending) 
+    {
+      switch (gDBView.sortType) 
+      {
+        case nsMsgViewSortType.byDate: 
+        case nsMsgViewSortType.byId: 
+        case nsMsgViewSortType.byThread: 
+         scrolled = ScrollToMessage(nsMsgNavigationType.lastMessage, true, false /* selectMessage */);
+         break;
+      }
+    }
+      
+    // if still we haven't scrolled,
+    // scroll to the top.
+    if (!scrolled)
+      EnsureRowInThreadTreeIsVisible(0);
+  }   
+  
+  return scrolled;
+}
+
 // the folderListener object
 var folderListener = {
-    OnItemAdded: function(parentItem, item, view) { },
+    OnItemAdded: function(parentItem, item) { },
 
-    OnItemRemoved: function(parentItem, item, view) { },
+    OnItemRemoved: function(parentItem, item) { },
 
     OnItemPropertyChanged: function(item, property, oldValue, newValue) { },
 
     OnItemIntPropertyChanged: function(item, property, oldValue, newValue) {
-      var currentLoadedFolder = GetThreadPaneFolder();
-      if (!currentLoadedFolder) return;
-      var currentURI = currentLoadedFolder.URI;
-
-      //if we don't have a folder loaded, don't bother.
-      if(currentURI) {
+      if (item == msgWindow.openFolder) {
         if(property.toString() == "TotalMessages" || property.toString() == "TotalUnreadMessages") {
-          var folder = item.QueryInterface(Components.interfaces.nsIMsgFolder);
-          if(folder) {
-            var folderResource = folder.QueryInterface(Components.interfaces.nsIRDFResource); 
-            if(folderResource) {
-              var folderURI = folderResource.Value;
-              if(currentURI == folderURI) {
-                UpdateStatusMessageCounts(folder);
-              }
-            }
-          }
+          UpdateStatusMessageCounts(gMsgFolderSelected);
         }      
       }
     },
@@ -111,11 +143,13 @@ var folderListener = {
        var eventType = event.toString();
        if (eventType == "FolderLoaded") {
          if (folder) {
+           var msgFolder = folder.QueryInterface(Components.interfaces.nsIMsgFolder);
            var uri = folder.URI;
-           if (uri == gCurrentFolderToReroot) {
+           var rerootingFolder = (uri == gCurrentFolderToReroot);
+           if (rerootingFolder) {
+             viewDebug("uri = gCurrentFolderToReroot, setting gQSViewIsDirty\n");
              gQSViewIsDirty = true;
              gCurrentFolderToReroot = null;
-             var msgFolder = folder.QueryInterface(Components.interfaces.nsIMsgFolder);
              if(msgFolder) {
                msgFolder.endFolderLoading();
                // suppress command updating when rerooting the folder
@@ -139,7 +173,7 @@ var folderListener = {
                  gDBView.suppressCommandUpdating = false;
                }
 
-               gIsEditableMsgFolder = IsSpecialFolder(msgFolder, MSG_FOLDER_FLAG_DRAFTS);
+               gIsEditableMsgFolder = IsSpecialFolder(msgFolder, MSG_FOLDER_FLAG_DRAFTS, true);
 
                gCurrentLoadingFolderSortType = 0;
                gCurrentLoadingFolderSortOrder = 0;
@@ -165,53 +199,10 @@ var folderListener = {
              }
            }
            if (uri == gCurrentLoadingFolderURI) {
-             // NOTE,
-             // if you change the scrolling code below,
-             // double check the scrolling logic in
-             // searchBar.js, restorePreSearchView()
-
+             viewDebug("uri == current loading folder uri\n");
              gCurrentLoadingFolderURI = "";
 
-             // if we didn't just scroll, 
-             // scroll to the first new message
-             // but don't select it
-             if (!scrolled)
-               scrolled = ScrollToMessage(nsMsgNavigationType.firstNew, true, false /* selectMessage */);
-
-             if (!scrolled && pref.getBoolPref("mailnews.remember_selected_message")) {
-               // if we failed to scroll to a new message,
-               // reselect the last selected message
-               var lastMessageLoaded = msgFolder.lastMessageLoaded;
-                 
-               if (lastMessageLoaded != nsMsgKey_None) {
-                 scrolled = SelectAndScrollToKey(lastMessageLoaded);
-               }
-             }
-
-             if (!scrolled) {
-               // if we still haven't scrolled,
-               // scroll to the newest, which might be the top or the bottom
-               // depending on our sort order and sort type
-               if (gDBView.sortOrder == nsMsgViewSortOrder.ascending) {
-                 switch (gDBView.sortType) {
-                   case nsMsgViewSortType.byDate: 
-                   case nsMsgViewSortType.byId: 
-                   case nsMsgViewSortType.byThread: 
-                     scrolled = ScrollToMessage(nsMsgNavigationType.lastMessage, true, false /* selectMessage */);
-                     break;
-                 }
-               }
-
-               // if still we haven't scrolled,
-               // scroll to the top.
-               if (!scrolled)
-                 EnsureRowInThreadTreeIsVisible(0);
-             }            
-
-             // NOTE,
-             // if you change the scrolling code above,
-             // double check the scrolling logic in
-             // searchBar.js, restorePreSearchView()
+             scrolled = ScrollToMessageAfterFolderLoad(msgFolder);   
 
              SetBusyCursor(window, false);
            }
@@ -227,19 +218,51 @@ var folderListener = {
               }
            }
            //folder loading is over, now issue quick search if there is an email address
-           if (gSearchEmailAddress)
+           viewDebug("in folder loaded gVirtualFolderTerms = " + gVirtualFolderTerms + "\n");
+           viewDebug("in folder loaded gMsgFolderSelected = " + gMsgFolderSelected.URI + "\n");
+           if (rerootingFolder)
            {
-             Search(gSearchEmailAddress);
-             gSearchEmailAddress = null;
-           } 
-           else if (gDefaultSearchViewTerms)
-           {
-             Search("");
+             if (gSearchEmailAddress)
+             {
+               Search(gSearchEmailAddress);
+               gSearchEmailAddress = null;
+             } 
+             else if (gVirtualFolderTerms)
+             {
+                gDefaultSearchViewTerms = null;
+                viewDebug("searching gVirtualFolderTerms\n");
+                loadVirtualFolder(); 
+             }
+             else if (gMsgFolderSelected.flags & MSG_FOLDER_FLAG_VIRTUAL)
+             {
+                viewDebug("selected folder is virtual\n");
+                gDefaultSearchViewTerms = null;
+             }
+             else
+             {               
+               // get the view value from the folder
+               if (msgFolder)
+               {
+                 var msgDatabase = msgFolder.getMsgDatabase(msgWindow);
+                 var dbFolderInfo = msgDatabase.dBFolderInfo; 
+                 var result = dbFolderInfo.getUint32Property("current-view", 0);
+                 
+                 // if our new view is the same as the old view and we already have the list of search terms built up
+                 // for the old view, just re-use it
+                 if (gCurrentViewValue == result && gDefaultSearchViewTerms)
+                 {
+                   viewDebug("searching gDefaultSearchViewTerms and rerootingFolder\n");
+                   Search("");
+                 }
+                 else
+                 {
+                   viewDebug("changing view by value\n");
+                   ViewChangeByValue(result);
+                 }
+               }
+             }
            }
-           else {
-             ViewChangeByValue(pref.getIntPref("mailnews.view.last"));
-           }
-         }
+         } 
        } 
        else if (eventType == "ImapHdrDownloaded") {
          if (folder) {
@@ -281,14 +304,9 @@ var folderListener = {
 }
 
 var folderObserver = {
-    canDropOn: function(index)
+    canDrop: function(index, orientation)
     {
-        return CanDropOnFolderTree(index);
-    },
-
-    canDropBeforeAfter: function(index, before)
-    {
-        return CanDropBeforeAfterFolderTree(index, before);
+        return CanDropOnFolderTree(index, orientation);
     },
 
     onDrop: function(row, orientation)
@@ -312,15 +330,6 @@ var folderObserver = {
     {
     },
 
-    isEditable: function(row, colID)
-    {
-        return false;
-    },
-
-    onSetCellText: function(row, colID, value)
-    {
-    },
-
     onPerformAction: function(action)
     {
     },
@@ -329,7 +338,7 @@ var folderObserver = {
     {
     },
 
-    onPerformActionOnCell: function(action, row, colID)
+    onPerformActionOnCell: function(action, row, col)
     {
     }
 }
@@ -523,20 +532,30 @@ function LoadCurrentlyDisplayedMessage()
 
 function IsCurrentLoadedFolder(folder)
 {
-	var msgfolder = folder.QueryInterface(Components.interfaces.nsIMsgFolder);
-	if(msgfolder)
-	{
-		var folderResource = msgfolder.QueryInterface(Components.interfaces.nsIRDFResource);
-		if(folderResource)
-		{
-			var folderURI = folderResource.Value;
-			var currentLoadedFolder = GetThreadPaneFolder();
-			var currentURI = currentLoadedFolder.URI;
-			return(currentURI == folderURI);
-		}
-	}
+  var msgfolder = folder.QueryInterface(Components.interfaces.nsIMsgFolder);
+  if(msgfolder)
+  {
+    var folderResource = msgfolder.QueryInterface(Components.interfaces.nsIRDFResource);
+    if(folderResource)
+    {
+      var folderURI = folderResource.Value;
+      var currentLoadedFolder = GetThreadPaneFolder();
+      if (currentLoadedFolder.flags & MSG_FOLDER_FLAG_VIRTUAL)
+      {
+        var msgDatabase = currentLoadedFolder.getMsgDatabase(msgWindow);
+        var dbFolderInfo = msgDatabase.dBFolderInfo;
+        var srchFolderUri = dbFolderInfo.getCharPtrProperty("searchFolderUri");
+        var re = new RegExp("^" + folderURI + "$|^" + folderURI + "\||\|" + folderURI + "$|\|" + folderURI +"\|");
+        var retval = (currentLoadedFolder.URI.match(re));
+        return retval;
 
-	return false;
+      }
+      var currentURI = currentLoadedFolder.URI;
+      return(currentURI == folderURI);
+    }
+  }
+
+  return false;
 }
 
 function ServerContainsFolder(server, folder)
@@ -602,6 +621,12 @@ var gThreePaneIncomingServerListener = {
 function UpdateMailPaneConfig(aMsgWindowInitialized) {
   var paneConfig = pref.getIntPref("mail.pane_config.dynamic");
   
+  if (paneConfig == kStandardPaneConfig)
+    document.getElementById('messagepanebox').setAttribute('flex', 1);
+  else 
+    document.getElementById('messagepanebox').removeAttribute('flex');
+    
+  
   // don't do anything if we are already in the correct configuration
   if (paneConfig == gCurrentPaneConfig)
     return;
@@ -690,6 +715,28 @@ function OnLoadMessenger()
   // update the pane config before we exit onload otherwise the user may see a flicker if we poke the document
   // in delayedOnLoadMessenger...
   UpdateMailPaneConfig(false);
+  document.loadBindingDocument('chrome://global/content/bindings/textbox.xml');
+
+  // Set a sane starting width/height for all resolutions on new profiles. Do this before the window loads
+  if (!document.documentElement.hasAttribute("width")) 
+  {
+    var defaultWidth, defaultHeight;
+    if (screen.availHeight <= 600) 
+    { 
+      document.documentElement.setAttribute("sizemode", "maximized");
+      defaultWidth = 800;
+      defaultHeight = 565;
+    }
+    else // for higher resolution displays, use larger values for height and width
+    {
+      defaultWidth = screen.availWidth * .8;
+      defaultHeight = screen.availHeight * .8; 
+    }
+
+    document.documentElement.setAttribute("width", defaultWidth);
+    document.documentElement.setAttribute("height", defaultHeight);
+  }
+
 
   setTimeout(delayedOnLoadMessenger, 0); // when debugging, set this to 5000, so you can see what happens after the window comes up.
 }
@@ -697,7 +744,7 @@ function OnLoadMessenger()
 /* Functions related to startup */
 function delayedOnLoadMessenger()
 {
-  pref.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
+  pref.QueryInterface(Components.interfaces.nsIPrefBranch2);
   pref.addObserver("mail.pane_config.dynamic", MailPrefObserver, false);
   pref.addObserver("mail.showFolderPaneColumns", MailPrefObserver, false);
 
@@ -705,7 +752,7 @@ function delayedOnLoadMessenger()
   CreateMailWindowGlobals();
   verifyAccounts(null);
     
-  HideAccountCentral();
+  ShowThreadPane();
   InitMsgWindow();
   messenger.SetWindow(window, msgWindow);
 
@@ -713,51 +760,32 @@ function delayedOnLoadMessenger()
   InitPanes();
 
   accountManager.setSpecialFolders();
+  accountManager.loadVirtualFolders();
   accountManager.addIncomingServerListener(gThreePaneIncomingServerListener);
 
   AddToSession();
+
   //need to add to session before trying to load start folder otherwise listeners aren't
   //set up correctly.
   // argument[0] --> folder uri
   // argument[1] --> optional message key
   // argument[2] --> optional email address; //will come from aim; needs to show msgs from buddy's email address  
-  if ("arguments" in window && window.arguments[0])
+  if ("arguments" in window)
   {
-    gStartFolderUri = window.arguments[0];
-    gStartMsgKey = window.arguments[1];
-    gSearchEmailAddress = window.arguments[2];
-
-  }
-  else
-  {
-    gStartFolderUri = null;
-    gStartMsgKey = nsMsgKey_None;
-    gSearchEmailAddress = null;
-  }
-
-  if (this.CheckForUnsentMessages != undefined && CheckForUnsentMessages())
-  {
-    var ioService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
-    if (!ioService.offline) 
+    // filter our any feed urls that came in as arguments to the new window...
+    if (window.arguments.length && /^feed:/i.test(window.arguments[0] ))
     {
-      InitPrompts();
-      InitServices();
-
-      if (gPromptService) 
-      {
-        var buttonPressed = gPromptService.confirmEx(window, 
-                            gOfflinePromptsBundle.getString('sendMessagesOfflineWindowTitle'), 
-                            gOfflinePromptsBundle.getString('sendMessagesLabel'),
-                            gPromptService.BUTTON_TITLE_IS_STRING * (gPromptService.BUTTON_POS_0 + 
-                              gPromptService.BUTTON_POS_1),
-                            gOfflinePromptsBundle.getString('sendMessagesSendButtonLabel'),
-                            gOfflinePromptsBundle.getString('sendMessagesNoSendButtonLabel'),
-                            null, null, {value:0});
-        if (buttonPressed == 0) 
-          SendUnsentMessages();
-      }
+      var feedHandler = Components.classes["@mozilla.org/newsblog-feed-downloader;1"].getService(Components.interfaces.nsINewsBlogFeedDownloader);
+      if (feedHandler)
+        feedHandler.subscribeToFeed(window.arguments[0], null, msgWindow);
+      gStartFolderUri = null;
     }
+    else
+      gStartFolderUri = (window.arguments.length > 0) ? window.arguments[0] : null;
+    gStartMsgKey = (window.arguments.length > 1) ? window.arguments[1]: nsMsgKey_None;
+    gSearchEmailAddress = (window.arguments.length > 2) ? window.arguments[2] : null;
   }
+
   setTimeout("loadStartFolder(gStartFolderUri);", 0);
 
   // FIX ME - later we will be able to use onload from the overlay
@@ -780,8 +808,9 @@ function delayedOnLoadMessenger()
 
 function OnUnloadMessenger()
 {
+  OnLeavingFolder(gMsgFolderSelected);  // mark all read in current folder
   accountManager.removeIncomingServerListener(gThreePaneIncomingServerListener);
-  pref.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
+  pref.QueryInterface(Components.interfaces.nsIPrefBranch2);
   pref.removeObserver("mail.pane_config.dynamic", MailPrefObserver);
   pref.removeObserver("mail.showFolderPaneColumns", MailPrefObserver);
 
@@ -801,26 +830,12 @@ function NotifyObservers(aSubject, aTopic, aData)
 // PerformExpand() for all servers that are open at startup.            
 function PerformExpandForAllOpenServers()
 {
-    var folderTree = GetFolderTree();
-    var view = folderTree.treeBoxObject.view;
-    for (var i = 0; i < view.rowCount; i++)
+    var servers = accountManager.allServers;
+    for (var i = 0; i < servers.Count(); i++)
     {
-        if (view.isContainer(i))
-        {
-            var folderResource = GetFolderResource(folderTree, i);
-            var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
-            var isServer = GetFolderAttribute(folderTree, folderResource, "IsServer"); 
-            if (isServer == "true")
-            {
-                if (view.isContainerOpen(i))
-                {
-                    var server = msgFolder.server;
-                    // Don't do this for imap servers. See bug #41943
-                    if (server.type != "imap")
-                        server.performExpand(msgWindow);
-                }
-            }
-        }
+        var server = servers.QueryElementAt(i, Components.interfaces.nsIMsgIncomingServer);
+        if (server.type != "imap" && !server.rootMsgFolder.getFlag(MSG_FOLDER_FLAG_ELIDED))
+            server.performExpand(msgWindow);
     }
 }
 
@@ -881,15 +896,15 @@ function loadStartFolder(initialUri)
         // the folder. i.e. the user just clicked on a news folder they aren't subscribed to from a browser
         // the news url comes in here.   
 
-        SelectFolder(startFolder.URI);        
+        // Perform biff on the server to check for new mail, except for imap
+        // or a pop3 account that is deferred or deferred to,
+        // or the case where initialUri is non-null (non-startup)
+        if (!initialUri && isLoginAtStartUpEnabled && gLoadStartFolder
+            && !defaultServer.isDeferredTo &&
+            defaultServer.rootFolder == defaultServer.rootMsgFolder)
+          defaultServer.PerformBiff(msgWindow);        
 
-        // only do this on startup, when we pass in null
-        if (!initialUri && isLoginAtStartUpEnabled && gLoadStartFolder)
-        {
-            // Perform biff on the server to check for new mail, except for imap
-            if (defaultServer.type != "imap")
-              defaultServer.PerformBiff(msgWindow);        
-        }
+        SelectFolder(startFolder.URI);        
 
 
         // because the "open" state persists, we'll call
@@ -912,16 +927,35 @@ function loadStartFolder(initialUri)
       dump(ex);
       dump('Exception in LoadStartFolder caused by no default account.  We know about this\n');
     }
+    
+    // if gLoadStartFolder is true, then we must have just created a POP3 account
+    // and we aren't supposed to initially download mail. (Bug #270743)
+    if (gLoadStartFolder)
+      MsgGetMessagesForAllServers(defaultServer);
 
-    MsgGetMessagesForAllServers(defaultServer);
-}
+    if (this.CheckForUnsentMessages != undefined && CheckForUnsentMessages())
+    {
+      var ioService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
+      if (!ioService.offline) 
+      {
+        InitPrompts();
+        InitServices();
 
-function TriggerGetMessages(server)
-{
-    // downloadMessagesAtStartup for a given server type indicates whether 
-    // or not there is a need to Trigger GetMessages action
-    if (server.downloadMessagesAtStartup)
-        MsgGetMessage();
+        if (gPromptService) 
+        {
+          var buttonPressed = gPromptService.confirmEx(window, 
+                            gOfflinePromptsBundle.getString('sendMessagesOfflineWindowTitle'), 
+                            gOfflinePromptsBundle.getString('sendMessagesLabel'),
+                            gPromptService.BUTTON_TITLE_IS_STRING * (gPromptService.BUTTON_POS_0 + 
+                            gPromptService.BUTTON_POS_1),
+                            gOfflinePromptsBundle.getString('sendMessagesSendButtonLabel'),
+                            gOfflinePromptsBundle.getString('sendMessagesNoSendButtonLabel'),
+                            null, null, {value:0});
+          if (buttonPressed == 0) 
+            SendUnsentMessages();
+        }
+      }
+    }
 }
 
 function AddToSession()
@@ -1049,12 +1083,6 @@ function UpgradeThreadPaneUI()
           // date column. 
           var dateCol = document.getElementById("dateCol");
           threadTree._reorderColumn(junkCol, dateCol, true);
-
-          // hide labels column by default
-          if (threadPaneUIVersion == 1) {
-            labelCol = document.getElementById("labelCol");
-            labelCol.setAttribute("hidden", "true");
-          }
         }
 
         var senderCol = document.getElementById("senderCol");
@@ -1192,13 +1220,13 @@ function ClearMessagePane()
   {
     gHaveLoadedMessage = false;
     gCurrentDisplayedMessage = null;
-    if (GetMessagePaneFrame().location != "about:blank")
-        GetMessagePaneFrame().location = "about:blank";
+    if (GetMessagePaneFrame().location.href != "about:blank")
+        GetMessagePaneFrame().location.href = "about:blank";
+    
     // hide the message header view AND the message pane...
     HideMessageHeaderPane();
-
-    // hide the junk bar
-    SetUpJunkBar(null);
+    gMessageNotificationBar.clearMsgNotifications();
+    ClearPendingReadTimer();
   }
 }
 
@@ -1207,7 +1235,7 @@ function GetSelectedFolderIndex()
     var folderTree = GetFolderTree();
     var startIndex = {};
     var endIndex = {};
-    folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+    folderTree.view.selection.getRangeAt(0, startIndex, endIndex);
     return startIndex.value;
 }
 
@@ -1216,27 +1244,24 @@ function GetSelectedFolderIndex()
 // It will also keep the outline/dotted line in the original row.
 function ChangeSelectionWithoutContentLoad(event, tree)
 {
-    var row = {};
-    var col = {};
-    var elt = {};
     var treeBoxObj = tree.treeBoxObject;
-    var treeSelection = treeBoxObj.selection;
+    var treeSelection = treeBoxObj.view.selection;
 
-    treeBoxObj.getCellAt(event.clientX, event.clientY, row, col, elt);
+    var row = treeBoxObj.getRowAt(event.clientX, event.clientY);
     // make sure that row.value is valid so that it doesn't mess up
     // the call to ensureRowIsVisible().
-    if((row.value >= 0) && !treeSelection.isSelected(row.value))
+    if((row >= 0) && !treeSelection.isSelected(row))
     {
         var saveCurrentIndex = treeSelection.currentIndex;
         treeSelection.selectEventsSuppressed = true;
-        treeSelection.select(row.value);
+        treeSelection.select(row);
         treeSelection.currentIndex = saveCurrentIndex;
-        treeBoxObj.ensureRowIsVisible(row.value);
+        treeBoxObj.ensureRowIsVisible(row);
         treeSelection.selectEventsSuppressed = false;
 
         // Keep track of which row in the thread pane is currently selected.
         if(tree.id == "threadTree")
-          gThreadPaneCurrentSelectedIndex = row.value;
+          gThreadPaneCurrentSelectedIndex = row;
     }
     event.preventBubble();
 }
@@ -1275,14 +1300,13 @@ function FolderPaneOnClick(event)
 
     if (elt.value == "twisty")
     {
-        var folderResource = GetFolderResource(folderTree, row.value);
-        var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
-
         if (!(folderTree.treeBoxObject.view.isContainerOpen(row.value)))
         {
+            var folderResource = GetFolderResource(folderTree, row.value);
             var isServer = GetFolderAttribute(folderTree, folderResource, "IsServer");
             if (isServer == "true")
             {
+                var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
                 var server = msgFolder.server;
                 server.performExpand(msgWindow);
             }
@@ -1304,10 +1328,6 @@ function FolderPaneOnClick(event)
     else if (event.detail == 2) {
       FolderPaneDoubleClick(row.value, event);
     }
-    else if (gDBView && gDBView.viewType == nsMsgViewType.eShowQuickSearchResults)
-    {
-      onClearSearch();
-    }
 
 }
 
@@ -1315,13 +1335,13 @@ function FolderPaneDoubleClick(folderIndex, event)
 {
     var folderTree = GetFolderTree();
     var folderResource = GetFolderResource(folderTree, folderIndex);
-    var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
-    var isServer = GetFolderAttribute(folderTree, folderResource, "IsServer");
 
+    var isServer = GetFolderAttribute(folderTree, folderResource, "IsServer");
     if (isServer == "true")
     {
       if (!(folderTree.treeBoxObject.view.isContainerOpen(folderIndex)))
       {
+        var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
         var server = msgFolder.server;
         server.performExpand(msgWindow);
       }
@@ -1343,7 +1363,7 @@ function ChangeSelection(tree, newIndex)
 {
     if(newIndex >= 0)
     {
-        tree.treeBoxObject.selection.select(newIndex);
+        tree.view.selection.select(newIndex);
         tree.treeBoxObject.ensureRowIsVisible(newIndex);
     }
 }
@@ -1353,13 +1373,13 @@ function GetSelectedFolders()
     var folderArray = [];
     var k = 0;
     var folderTree = GetFolderTree();
-    var rangeCount = folderTree.treeBoxObject.selection.getRangeCount();
+    var rangeCount = folderTree.view.selection.getRangeCount();
 
     for(var i = 0; i < rangeCount; i++)
     {
         var startIndex = {};
         var endIndex = {};
-        folderTree.treeBoxObject.selection.getRangeAt(i, startIndex, endIndex);
+        folderTree.view.selection.getRangeAt(i, startIndex, endIndex);
         for (var j = startIndex.value; j <= endIndex.value; j++)
         {
             var folderResource = GetFolderResource(folderTree, j);
@@ -1375,19 +1395,18 @@ function GetSelectedMsgFolders()
     var folderArray = [];
     var k = 0;
     var folderTree = GetFolderTree();
-    var rangeCount = folderTree.treeBoxObject.selection.getRangeCount();
+    var rangeCount = folderTree.view.selection.getRangeCount();
 
     for(var i = 0; i < rangeCount; i++)
     {
         var startIndex = {};
         var endIndex = {};
-        folderTree.treeBoxObject.selection.getRangeAt(i, startIndex, endIndex);
+        folderTree.view.selection.getRangeAt(i, startIndex, endIndex);
         for (var j = startIndex.value; j <= endIndex.value; j++)
         {
           var folderResource = GetFolderResource(folderTree, j); 
           if (folderResource.Value != "http://home.netscape.com/NC-rdf#PageTitleFakeAccount") {
             var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
-
             if(msgFolder)
               folderArray[k++] = msgFolder;
           }
@@ -1491,7 +1510,7 @@ function NumberOfSelectedMessagesAboveCurrentIndex(index)
 
 function SetNextMessageAfterDelete()
 {
-  var treeSelection = GetThreadTree().treeBoxObject.selection;
+  var treeSelection = GetThreadTree().view.selection;
 
   if (treeSelection.isSelected(treeSelection.currentIndex))
     gNextMessageViewIndexAfterDelete = gDBView.msgToSelectAfterDelete;
